* project: "The labour market and poverty impacts of Covid-19 in South Africa" (15 July 2020 Version)
* authors: Ronak Jain - rjain@g.harvard.edu, Joshua Budlender - jbudlender@umass.edu, Rocco Zizzamia - rocco.zizzamia@qeh.ox.ac.uk & Ihsaan Bassier - ibassier@umass.edu (randomised author order).
* link: https://cramsurvey.org/wp-content/uploads/2020/07/Jain-The-labour-market-and-poverty-impacts.pdf
********************************************************************************

* this code draws substantially from "Program 1 - Merging NIDS and NIDS-CRAM.do" released by NIDS-CRAM

* this file prepares a NIDS Wave 5 and NIDS-CRAM "wide" panel

* this file last updated on 21 July 2020
********************************************************************************
********************************************************************************


/* 
NIDS-CRAM
1 July 2020
Merging individuals and households across all waves.

NOTE TO USER
This do file merges all the individual level and household level datasets from wave 5 of NIDS with the NIDS-CRAM Wave 1 dataset. 
NIDS data files can be found here: https://www.datafirst.uct.ac.za/dataportal/index.php/catalog/NIDS/about

Note: 
1. The HHRoster is not merged in because of duplicates on pid as a result of multiple memberships allowed for an individual.
2. NIDS variables are prefaced with the wave number "w5", while NIDS-CRAM wave 1 variables are prefaced with "w1_nc". 

* NB
This do file does not create a balanced panel dataset and as such the interview outcomes need to be taken into account when performing analysis.

*/
 
*===========================================================================================================================================
* GLOBALS FOR DATA FILES AND VERSION SUFFIXES

	global NIDSW5 "" 	//File path to where data is located. Change this path according to where your data folder is located on your computer.
	global CRAMW1 ""

*===========================================================================================================================================

clear all
set more off
set maxvar 20000 

// Appending Individual level data sets from NIDS and merging to the household level data sets for each wave. NIDS-CRAM does not have separate 
// household and individual sub-datasets, so it is more straightforward to merge NIDS-CRAM with the NIDS data once the latter is all merged together. 


//GATHER NIDS WAVE 5
global VersionIN: dir "$NIDSW5" files "Adult*.dta", respectcase
global VersionIN = subinstr($VersionIN,"Adult_W5_","",.)
global VersionIN = subinstr("$VersionIN",".dta","",.)

use "$NIDSW5\Adult_W5_$VersionIN.dta", clear
append using "$NIDSW5\Child_W5_$VersionIN.dta" "$NIDSW5\Proxy_W5_$VersionIN.dta"
merge m:1 w5_hhid using "$NIDSW5\HHQuestionnaire_W5_$VersionIN.dta", assert(match using)
assert w5_h_outcome == 6 if _merge == 2	

drop if _merge!=3
drop _merge
merge m:1 w5_hhid using "$NIDSW5\hhderived_W5_$VersionIN.dta", assert(match using)

drop if _merge!=3
drop _merge
merge 1:1 pid using "$NIDSW5\indderived_W5_$VersionIN.dta", assert(match)
drop _merge
save "$NIDSW5\wave5_merged.dta", replace


//GATHER CRAM WAVE 1
use "$CRAMW1\NIDS-CRAM_Wave1_W1_Anon_V1.0.0.dta", clear		
merge 1:1 pid using "$CRAMW1\derived_NIDS-CRAM_Wave1_W1_Anon_V1.0.0.dta", assert(match)	
drop _merge

cap drop w1_nc_deflator
gen w1_nc_deflator=.
replace w1_nc_deflator=115.2/115.6 
lab var w1_nc_deflator "NIDS-CRAM 1 deflator"

save "$CRAMW1\nc_merged_v1.dta", replace			


//MERGE NIDS W5 + CRAM W1
use "$NIDSW5\wave5_merged.dta", clear
merge 1:1 pid using "$CRAMW1\nc_merged_v1.dta", assert(master match) 
drop _merge
save "$CRAMW1\nidscram_merged_v1.dta", replace 	


use "$CRAMW1\Link_File_NIDS-CRAM_Wave1_W1_Anon_V1.0.0.dta", clear	
merge 1:1 pid using "$CRAMW1\nidscram_merged_v1.dta", assert(match using)	
cap drop _merge

*NIDS w5 deflators moved here. (see below)
****
scalar base=115.2 								//Set scalar to base month, currently Feb 2020

gen w5_deflator=.
replace w5_deflator=base/100.6 if w5_h_intrv_m==1 & w5_h_intrv_y==2017
replace w5_deflator=base/101.7 if w5_h_intrv_m==2 & w5_h_intrv_y==2017
replace w5_deflator=base/102.3 if w5_h_intrv_m==3 & w5_h_intrv_y==2017
replace w5_deflator=base/102.4 if w5_h_intrv_m==4 & w5_h_intrv_y==2017
replace w5_deflator=base/102.7 if w5_h_intrv_m==5 & w5_h_intrv_y==2017
replace w5_deflator=base/102.9 if w5_h_intrv_m==6 & w5_h_intrv_y==2017
replace w5_deflator=base/103.2 if w5_h_intrv_m==7 & w5_h_intrv_y==2017
replace w5_deflator=base/103.3 if w5_h_intrv_m==8 & w5_h_intrv_y==2017
replace w5_deflator=base/103.8 if w5_h_intrv_m==9 & w5_h_intrv_y==2017
replace w5_deflator=base/104.1 if w5_h_intrv_m==10 & w5_h_intrv_y==2017
replace w5_deflator=base/104.2 if w5_h_intrv_m==11 & w5_h_intrv_y==2017
replace w5_deflator=base/104.7 if w5_h_intrv_m==12 & w5_h_intrv_y==2017

replace w5_deflator=base/102.4 if w5_h_intrv_m==. & w5_h_outcome==1

lab var w5_deflator "Wave 5 deflator"
****

save "$CRAMW1\w5_nc_v1.dta", replace	

*===========================================================================================================================================

erase "$NIDSW5\wave5_merged.dta"
erase "$CRAMW1\nc_merged_v1.dta" 
erase "$CRAMW1\nidscram_merged_v1.dta" 

*===========================================================================================================================================


duplicates report pid
assert r(unique_value) == r(N)

save "$CRAMW1\w5_nc_v1.dta", replace 

*THE END
