* project: "The labour market and poverty impacts of Covid-19 in South Africa" (15 July 2020 Version)
* authors: Ronak Jain - rjain@g.harvard.edu, Joshua Budlender - jbudlender@umass.edu, Rocco Zizzamia - rocco.zizzamia@qeh.ox.ac.uk & Ihsaan Bassier - ibassier@umass.edu (randomised author order).
* link: https://cramsurvey.org/wp-content/uploads/2020/07/Jain-The-labour-market-and-poverty-impacts.pdf
********************************************************************************

* this file contains our main analysis. 

* this file last updated on 21 July 2020

********************************************************************************
********************************************************************************


*******FILE PURPOSE: Pre-Analysis, Post-first clean file for analysis of the CRAM DATA 
*TABLES AND FIGURES 

clear all
set more off
set maxvar 25000
capture log close
set scheme plotplain

	global cram ""		// directory in which "Data" and "do files" are contained as sub-directories
	global trash ""		// some other directory (useful to have on local machine if main files are stored on dropbox, and have slow internet connection)


use "${cram}\Data\Data\w5_nc_v1.dta", clear
do "${cram}\do files\5.5a. Jain_NIDSw5_NIDS-CRAM_mainclean_w1.do"
drop if nids_sample==.
keep w6_totwage* w6_empcat* w6_age w6_gender w6_area w6_occu w5_a_em1contr w6_race w6_wgt w6_educ_bins pid w5_hhincomepc~4 w6_emdays_feb~p w6_emdays_apr~p cluster stratum w6_hhincloss_main  w6_metro cover_grnt_unemp cover_grnt_ters w6_hhfdyn jobloss_* w6_hhsizer w6_hhincome w5_formal w5_hhincome w5_hhq_inc w6_hhincome w6_hhincome_cl w6_hhincome_imp w6_guess_hhid w5_hhsizer w6_prov w5_prov w6_dc2011 w5_dc2011 w6_hhincloss_any w5_hhincomepc w6_csg_number w6_oap_number w5_hhdependents
numlabel, add
g w6_fwgt= round(w6_wgt)
save "$trash\temp.dta", replace



***************************************************************
*SETUP TO KEEP HERE
***************************************************************

//Keep only working age pop (deletes 10%)
keep if inrange(w6_age, 18,64)


//dummies

*Youth 
g youth= w6_age<=35 if w6_age<=55


g female= w6_gender==2 if w6_gender!=.
g urban= w6_area==2 if w6_area!=.

g age2=w6_age^2


*Tertiary vs others
g tertiary= w6_educ_bins==4 if w6_educ_bins!=.


*Informal 2017
g  contract= w5_formal==1 if w5_formal!=.


*Emp dummies
cap drop empfeb? empapr?
tab w6_empcat_feb if w6_empcat_feb!=., gen(empfeb)
tab w6_empcat_apr if w6_empcat_apr!=., gen(empapr) 


//Earnings: conditional, unconditional and job retainers
g earn_apr_con= w6_totwage_apr if w6_totwage_apr>0 &  w6_totwage_apr!=.
g earn_feb_con= w6_totwage_feb if w6_totwage_feb>0 & w6_totwage_feb!=.
g earn_apr_uncon= earn_apr_con
replace earn_apr_uncon= 0 if earn_apr_con==. 
g earn_feb_uncon= earn_feb_con
replace earn_feb_uncon= 0 if earn_feb_con==.

*Change in income for continued pos wage
g earn_apr_inc= earn_apr_con if earn_apr_con!=. & earn_feb_con!=.
g earn_feb_inc= earn_feb_con if earn_apr_con!=. & earn_feb_con!=.
g earn_changecat1= (earn_feb_inc>earn_apr_inc) if earn_apr_inc!=.
g earn_changecat2= (earn_feb_inc==earn_apr_inc) if earn_apr_inc!=. 
g earn_changecat3= (earn_feb_inc<earn_apr_inc) if earn_apr_inc!=. 

*Change in days for cont pos wage (set to 0 days if missing)
g hrs_apr_inc= w6_emdays_apr_imp if earn_apr_inc!=.
replace hrs_apr_inc=0 if hrs_apr_inc==. & earn_apr_inc!=.
g hrs_feb_inc= w6_emdays_feb_imp if earn_apr_inc!=.
replace hrs_feb_inc=0 if hrs_feb_inc==. & earn_apr_inc!=.

g hrs_changecat1= (hrs_feb_inc>hrs_apr_inc) if hrs_apr_inc!=.
g hrs_changecat2= (hrs_feb_inc==hrs_apr_inc) if hrs_apr_inc!=.
g hrs_changecat3= (hrs_feb_inc<hrs_apr_inc) if hrs_apr_inc!=. 
drop hrs_*_inc earn_*_inc



*quartiles 
xtile earn_feb_conq= earn_feb_con [aw=w6_wgt], n(4)
recode earn_feb_conq (1 2=1)(3=2)(4=3)


//Occupations
recode w6_occu (1/3= 1 "Professionals")(4/8= 2 "Service/Operators") (9= 3 "Manual")(*=.), gen(occupcat)


//Days 
foreach var in feb apr {
	g days_`var'0= (w6_emdays_`var'_imp==. | w6_emdays_`var'_imp==0)
	g days_`var'1= inrange(w6_emdays_`var'_imp, 1,4)
	g days_`var'2= inrange(w6_emdays_`var'_imp, 5,7)
}
*conditional on positive earnings
foreach var in feb apr {
	forval i=0/2 {
		g days_`var'`i'con= days_`var'`i' if earn_`var'_con!=.
	}
}


//HHincome (use without outliers)

*pc
g w6_hhincomepc= w6_hhincome_cl/w6_hhsizer
cap g lnhhincomepc= ln(w6_hhincomepc)

*poverty
g foodpov= w6_hhincomepc<580 if w6_hhincomepc!=.
g ubpov= w6_hhincomepc<1265 if w6_hhincomepc!=.

g w5_foodpov= w5_hhincomepc<580 if w5_hhincomepc!=.
g w5_ubpov= w5_hhincomepc<1265 if w5_hhincomepc!=.

*Poverty with grants
g w6_hhincomepc_wgrant= (w6_hhincome_cl + 300*w6_csg_number + 250*w6_oap_number)/w6_hhsizer
replace w6_hhincomepc_wgrant= w6_hhincomepc if w6_hhincomepc_wgrant==.

g foodpov_wgrant= w6_hhincomepc_wgrant<580 if w6_hhincomepc_wgrant!=.
g ubpov_wgrant= w6_hhincomepc_wgrant<1265 if w6_hhincomepc_wgrant!=.


*group q1 and q2 together for het 
g w5_hhincomepc_cat= 1 if w5_hhincomepc_q4==1 | w5_hhincomepc_q4==2
replace w5_hhincomepc_cat= 2 if w5_hhincomepc_q4==3
replace w5_hhincomepc_cat= 3 if w5_hhincomepc_q4==4


//HHincome loss
g w6_hhincloss_clean= (w6_hhincloss_main==1 | w6_hhincloss_any==1) if w6_hhincloss_main!=. & w6_hhincloss_any!=.
replace w6_hhincloss_clean= . if jobloss_34==1 & w6_hhincloss_clean==0

numlabel, add
save "${trash}\temp.dta", replace



//COLOR CODING
global emp1 "green%70"
global emp2 "gold%70"
global emp3 "orange%70"
global emp4 "maroon%90"





***************************************************************
*EXHIBIT 1: Panel A, Overall employment
***************************************************************


use "${trash}\temp.dta", clear

//Reshape for standard errors (ttest doesn't work with svy)
ren (empfeb1 empapr1) (emp1 emp2)
ren (empfeb2 empapr2) (paid1 paid2)
ren (empfeb3 empapr3) (unpaid1 unpaid2)
ren (empfeb4 empapr4) (unemp1 unemp2)
keep pid emp? paid? unpaid? unemp? w6_wgt cluster stratum 
reshape long emp paid unpaid unemp, i(pid) j(time)
g covid= time==2
svyset cluster [weight = w6_wgt], strata(stratum)


//Collect estimates
mat A = J(1,3,.) 
foreach var in emp paid unpaid unemp {
	svy: reg `var' if time==1
	mat t1= (_b[_cons], r(table)[5,1], r(table)[6,1])
	svy: reg `var' if time==2
	mat t2= (_b[_cons], r(table)[5,1], r(table)[6,1])
	svy: reg `var' covid
	mat t3= (_b[covid],  r(table)[5,1], r(table)[6,1]) 
	mat A= (A \ t1 \ t2 \ t3)
}
mat A= A[2..., 1...]


//Collect estimates
clear 
svmat A
g id= _n
ren (A1 A2 A3)(b lb ub)
recode id (1/3=1)(4/6=2)(7/9=3)(10/12=4), gen(emptype)
recode id (1 4 7 10= 1)(2 5 8 11=2)(3 6 9 12=3), gen(month)


*Group by month
sort month emptype
g orderid= _n
*Create gaps for bars
forval i= 4(4)12 {
	replace orderid= orderid+1 if orderid>=`i'+`i'/4
}
*Adjust to percentages
foreach var in b lb ub {
	replace `var'= round(100*`var')
}


twoway (bar b orderid if emptype==1, col($emp1 )) ///
		(bar b orderid if emptype==2, col($emp2 )) ///
		(bar b orderid if emptype==3, col($emp3 )) ///
		(bar b orderid if emptype==4, col($emp4 )) ///
		(rcap ub lb orderid, col(gray%70)) ///
		(scatter b orderid, msym(none) mlab(b) mlabpos(11)), ///
		legend(row(2) order(1 "Working (days>0)" 2 "Paid leave (days=0,wage>0)" 3 "Temp. layoff (days=0, wage=0)" 4 "Not employed") pos(6)) ///
		xlabel( 2.5 "Pre-Lockdown (Feb)" 7.5 "Lockdown (Apr)" 12.5 "Change (Apr-Feb)", noticks) ///
		scheme(plotplain) xtitle("Employment status") ytitle("Pct. of working age adults")

graph export "${cram}\Figures\ex1a_empall_v2.pdf", replace
graph export "${cram}\Figures\ex1a_empall_v2.svg", replace

/*Notes
-- graph hack follows: https://stats.idre.ucla.edu/stata/faq/how-can-i-make-a-bar-graph-with-error-bars/
*/



*EX1app: Employment transition********************************

use "${trash}\temp.dta", clear

svyset cluster [weight = w6_wgt], strata(stratum)

mat A1a= J(1,3,.)
foreach j of numlist 1 4 {
forval i=1/4 {
	svy: mean empapr`i' if w6_empcat_feb==`j'
	mat t= (r(table)[1,1], r(table)[5,1], r(table)[6,1])
	mat A1a= (A1a \ t)
}
}
mat A1a= A1a[2..., 1...]


//Clean up
clear 
svmat A1a
g id= _n
ren (A1a1 A1a2 A1a3)(b lb ub)
recode id (1/4=1)(5/8=4), gen(emp_feb)
recode id (1 5= 1)(2 6=2)(3 7=3)(4 8=4), gen(emp_apr)
replace id= id+1 if id>=5

*Adjust to percentages
foreach var in b lb ub {
	replace `var'= round(100*`var')
}


twoway (bar b id if emp_apr==1, col($emp1 )) ///
		(bar b id if emp_apr==2, col($emp2 )) ///
		(bar b id if emp_apr==3, col($emp3 )) ///
		(bar b id if emp_apr==4, col($emp4 )) ///
		(rcap ub lb id, col(gray%70)) ///
		(scatter b id, msym(none) mlab(b) mlabpos(11)), ///
		legend(row(2) order(1 "Working (days>0), Apr" 2 "Paid leave (days=0,wage>0), Apr" 3 "Temp. layoff (days=0, wage=0), Apr" 4 "Not employed, Apr") pos(6)) ///
		xlabel( 2.5 "Working (days>0), Feb" 7.5 "Not employed, Feb", noticks) ///
		scheme(plotplain) xtitle("Change in employment status") ytitle("Pct. of employment category")

graph export "${cram}\Figures\ex1app_emptran_v2.pdf", replace
graph export "${cram}\Figures\ex1app_emptran_v2.svg", replace





***************************************************************
*EMP AND EARNINGS
***************************************************************
/*
Rows by: Age, Gender, Race, Education Bins, Employment Type Category (Self empl, etc), 2017 HH income pc
*/


//PROGRAM FOR STATS
cap prog drop t1stats
prog define t1stats
	syntax [if]
	
	foreach mo in feb apr {

	*Total emp in each category
	estpost tabstat emp`mo'1 emp`mo'2 emp`mo'3 emp`mo'4 `if' [fw=w6_fwgt], s(n mean)
	mat t`mo'= (e(emp`mo'1)[1,1], e(emp`mo'1)[1,2], e(emp`mo'2)[1,2], e(emp`mo'3)[1,2], e(emp`mo'4)[1,2])
	
	*Earnings stats
	estpost tabstat earn_`mo'_uncon `if' [fw=w6_fwgt], s(mean p10 p50 p90)
	mat t`mo'= (t`mo',  e(mean) , e(p10), e(p50), e(p90))
	
	*Days worked stats
	estpost tabstat days_`mo'0 days_`mo'1 days_`mo'2 `if' [fw=w6_fwgt], s(mean)
	mat t`mo'= (t`mo', e(days_`mo'0)[1,1], e(days_`mo'1)[1,1], e(days_`mo'2)[1,1])
	
	}

	mat B= (B \ tfeb \ tapr)
end 


//HETEROGENEITY CATEGORIES
cap prog drop t1hetcats
prog define t1hetcats
	syntax [if], progname(string)

	//ALL
	`progname'

	//FEMALE AND URBAN AND YOUTH
	foreach var in female tertiary {
		foreach i of numlist 0 1 {
			`progname' if `var'==`i' 
		}
	}

	//Occup cat and 2017 hhincome cats
	foreach var in occupcat w5_hhincomepc_cat {
	foreach i of numlist 1 2 3 {
		`progname' if `var'==`i'
	}
	}

	//2017 w5_a_em1contr_d
	foreach i of numlist 0 1 {
		`progname' if contract==`i' 
	}

end


use  "${trash}\temp.dta", clear
matrix B = J(1,12,.) 
t1hetcats, progname(t1stats)

mat coln B= "freq" "emp" "paidl" "unpaidl" "unemp" "earn mc" "earnp10uc" "earnp50uc" "earnp90uc" "hours0uc" "hoursptuc" "hoursftuc"
 
 
 
//EXHIBIT 1: PANEL B, HET EMP**************************************


//Labelling and grouping 
cap prog drop fig1hetcats
prog define fig1hetcats

	*Label bars (groups)
	lab def group 1 "All" 2 "Men" 3 "Women" 4 "<=12 years" 5 "Tertiary" 6 "Professionals" 7 "Service/Operators"  8 "Manual" 9 "Q1-2" 10 "Q3" 11 "Q4" 12 "Verbal" 13 "Written", modify
	lab val group group

	g supergroup= 1 if inlist(group, 1)
	replace supergroup= 2 if inlist(group, 2,3)
	replace supergroup= 3 if inlist(group, 4,5)
	replace supergroup= 4 if inlist(group, 6,7,8)
	replace supergroup= 5 if inlist(group, 9,10,11)
	replace supergroup= 6 if inlist(group, 12,13)
end


//NET CHANGE, % of employed 

//Prep matrix dataset of estimates
matrix A3 = J(1,3,.) 
mat T= B[2..., 1..5]
local numrows=  rowsof(T)	

*Take apr-feb proportions of adults
forval i= 2(2)`numrows' {
	mat t= ((T[`i',3]-T[`i'-1,3])/T[`i'-1,2]) 
	mat t= (t, (T[`i',4]-T[`i'-1,4])/T[`i'-1,2]) 
	mat t= (t, (T[`i',5]-T[`i'-1,5])/T[`i'-1,2]) 
	mat A3= (A3 \ t)
}

mat A3= A3[2...,1...]
mat A3= A3'

*Manipulate as stata dataset, cols are each group (eg men)
clear
xsvmat A3, names(cols) norestore


*Define emp cat
g empcat= 2 if _n==1
replace empcat= 3 if _n==2
replace empcat= 4 if _n==3

*Some juggling to get into shape for bar graph
reshape long cols, i(empcat)
ren (_j cols) (group emprate)
reshape wide emprate, i(group) j(empcat)
foreach var in emprate4 emprate3 emprate2 {
	replace `var'= `var'*100
}


//Labeling
fig1hetcats

graph bar (mean)  emprate4 emprate3 emprate2, stack over(group, label(angle(45) labsize(vsmall))) over(supergroup,  relabel(1 "All" 2 "Sex" 3 "Education" 4 "Occupation" 5 "HH income (2017)" 6 "Contract (2017)") label(labsize(small))) nofill leg(on pos(6) row(1) order(1 "Not employed" 2 "Temp. layoff (days=0,wage=0)" 3 "Paid leave (days=0,wage>0)")) bar(1, color($emp4)) bar(2, color($emp3)) bar(3, color($emp2)) yti("Net employment loss (pct of Feb)") blabel(bar, format(%2.0f) size(small) pos(center))

graph export "${cram}\Figures\ex1b_emphet_v3.pdf", replace
graph export "${cram}\Figures\ex1b_emphet_v3.svg", replace
graph export "${cram}\Figures\ex1b_emphet_v3.png", replace




//EMP CATS FOR JOB LOSS

cap prog drop t1bstats
prog define t1bstats
	syntax [if]
	
	estpost tabstat empapr2 empapr3 empapr4 [fw=w6_fwgt] `if', s(mean)
	mat t= (e(empapr2)[1,1], e(empapr3)[1,1], e(empapr4)[1,1])

	mat A4= (A4 \ t)
end 

use  "${trash}\temp.dta", clear
matrix A4 = J(1,3,.) 

//Restrict to job losers only!
keep if w6_empcat_feb==1 

//Collect estimates
t1hetcats, progname(t1bstats)


//Prep matrix dataset of estimates
mat A4= A4[2...,1...]
mat A4= A4'

clear
xsvmat A4, names(cols) norestore

*Define emp cat
g empcat= 2 if _n==1
replace empcat= 3 if _n==2
replace empcat= 4 if _n==3

*Some juggling to get into shape for bar graph
reshape long cols, i(empcat)
ren (_j cols) (group emprate)
reshape wide emprate, i(group) j(empcat)
foreach var in emprate4 emprate3 emprate2 {
	replace `var'= `var'*100
}


//Labeling
fig1hetcats

graph bar (mean)  emprate4 emprate3 emprate2, stack over(group, label(angle(45) labsize(vsmall))) over(supergroup,  relabel(1 "All" 2 "Sex" 3 "Education" 4 "Occupation" 5 "HH income (2017)" 6 "Contract (2017)") label(labsize(small))) nofill leg(on pos(6) row(1) order(1 "Not employed" 2 "Temp. layoff (days=0,wage=0)" 3 "Paid leave (days=0,wage>0)")) bar(1, color($emp4)) bar(2, color($emp3)) bar(3, color($emp2)) yti("Pct of Feb employed") blabel(bar, format(%2.0f) size(small) pos(center))

graph export "${cram}\Figures\ex1appb_jlossemphet_v3.pdf", replace
graph export "${cram}\Figures\ex1appb_jlossemphet_v3.svg", replace



//EXHIBIT 2: EARNINGS AND HOURS**********************************
/*

Superrows for conditional + unconditional; supercolumns for Hours + Earnings

Frequency (total, non-missing), 
Mean, Median, p(10), P(50), p(90);
Full time(35+), Part time, Zero - for hours (percentages) 

*/

use  "${trash}\temp.dta", clear

//PANEL A: ALL, UNCONDITIONAL, CONDITIONAL AND CHANGES

*Unconditional
mat B1= (B[2..3,1], B[2..3,6..9],100*B[2..3,10..12])
mat t= (.)
forval j=2/8 {
	mat t= (t, 100*(B1[2,`j']-B1[1,`j'])/B1[1,`j']) 
}
mat B1= (B1 \ t)

*Conditional
foreach mo in feb apr {
	estpost tabstat earn_`mo'_con [fw=w6_fwgt], stat(mean p10 p50 p90 n)
	mat t1`mo'= (e(count),e(mean),e(p10),e(p50),e(p90))
	
	estpost tabstat days_`mo'0con days_`mo'1con days_`mo'2con [fw=w6_fwgt]
	mat t1`mo'= (t1`mo', 100*e(days_`mo'0con)[1,1], 100*e(days_`mo'1con)[1,1], 100*e(days_`mo'2con)[1,1])
}
mat t= (.)
forval j=2/8 {
	mat t= (t, 100*(t1apr[1,`j']-t1feb[1,`j'])/t1feb[1,`j']) 
}
mat B1= (B1 \ t1feb \ t1apr \ t)

*Within-individual change
estpost tabstat earn_changecat1 earn_changecat2 earn_changecat3 hrs_changecat1 hrs_changecat2 hrs_changecat3 [fw=w6_fwgt], stat(mean n)
mat t= (e(earn_changecat1)[1,2],e(earn_changecat1)[1,1],e(earn_changecat2)[1,1],e(earn_changecat3)[1,1],e(hrs_changecat1)[1,1],e(hrs_changecat2)[1,1],e(hrs_changecat3)[1,1])
mat t= (t[1,1],.,100*t[1,2...])
mat B1= (B1 \ t)

mat rown B1= "uncon Feb" "uncon apr" "unconchange" "con Feb" "con apr" "conchange" "incchange" 
local numrows=  rowsof(B1)	
local numcols=  colsof(B1)	
forval i= 1/`numrows' {
	forval j= 1/`numcols' {
		mat B1[`i',`j']= round(B1[`i',`j'])
	}
}
mat list B1
esttab matrix(B1) using "${cram}\Figures\ex2_allearnhours_v3.csv", replace label nomtitle csv


//PANEL B: HETEROGENEITY, UNCONDITIONAL
mat T= (B[4..., 1], B[4..., 6..12])	
local numcols=  colsof(T)
mat B2= J(1,`numcols',.)

local numrows=  rowsof(T)
forval i= 2(2)`numrows' {
	*Store freq for apr only
	mat t= T[`i',1]
	
	*Earnings
	forval j=2/5 {
		mat t= (t, 100*(T[`i',`j']-T[`i'-1,`j'])/T[`i'-1,`j']) 
	}
	
	*Hours (convert to percentage)
	forval j=6/8 {
		mat t= (t, 100*(T[`i',`j']-T[`i'-1,`j'])/T[`i'-1,`j'])
	}
	mat B2= (B2 \ t)
}
mat B2= B2[2...,1...]


mat coln B2= "Freq" "Earn (mean)" "Earn (p10)" "Earn (p50)" "Earn (p90)"  "No workdays" "Part time"   "Full time" 
mat rown B2= "Men" "Women" "Educ<=12" "Tertiary" "Occup_prof" "Occup_serv" "Occup_manual" "hhincq1-2" "hhincq3" "hhincq4" "No_contract" "Contract"

local numrows=  rowsof(B2)	
local numcols=  colsof(B2)	
forval i= 1/`numrows' {
	forval j= 1/`numcols' {
		mat B2[`i',`j']= round(B2[`i',`j'])
	}
}
mat list B2

esttab matrix(B2) using "${cram}\Figures\ex2_earnhours_v3.csv", replace label nomtitle csv




//EXHIBIT 2: PANEL C, FREQ PLOT*********************************

use "${trash}\temp.dta", clear

keep earn_feb_uncon earn_apr_uncon pid w6_wgt cluster stratum
ren (earn_feb_uncon earn_apr_uncon)(earn1 earn2)
reshape long earn, i(pid) j(wave)

svyset cluster [weight = w6_wgt], strata(stratum)

egen earnbin= cut(earn), at(0 1(500)10000)
replace earnbin=-250 if earnbin==0
replace earnbin= earnbin + 250 if inrange(earnbin,1,10000)
g post= wave==2

mat B3= J(1,4,.)
foreach i of numlist -250 251(500)9251 {
	cap drop ind
	g ind= earnbin==`i'
	svy: reg ind post
	mat t= (`i',_b[post], r(table)[5,1], r(table)[6,1])
	mat B3= (B3 \ t)
}

clear
svmat B3
ren (B31 B32 B33 B34)(earnbin pctchange lb ub)
local tot=_N
foreach var in pctchange lb ub {
	replace `var'= round(1000*`var')/10
}

twoway (bar pctchange earnbin, col(red%50) barw(500)) (rcap ub lb earnbin, col(navy%70)) (scatter pctchange earnbin, msym(none) mlab(pctchange) mlabpos(1)), ytitle("Change in share of adults") leg(off) xti(Earnings bin (Rands p/m))
		
graph export "${cram}\Figures\ex2c_earnbins_v1.pdf", replace

		
***************************************************************
*EXHIBIT 3: SOCIAL PROTECTION
***************************************************************

use  "${trash}\temp.dta", clear

*Define only for employed in feb and by cat in apr 
tab cover_grnt_ters if w6_empcat_feb==1 & inlist(w6_empcat_apr, 2,3), gen(covters)
tab cover_grnt_unemp if w6_empcat_feb==1 & inlist(w6_empcat_apr, 4), gen(covunemp)


//PROGRAM FOR STATS
cap prog drop ex3stats
prog define ex3stats
	syntax [if]
	
	estpost tabstat covters1 covters2 covters3 covters4 covunemp1 covunemp2 covunemp3 covunemp4 `if' [fw=w6_fwgt]
	
	mat t= (e(covters1)[1,1], e(covters2)[1,1], e(covters3)[1,1], e(covters4)[1,1], e(covunemp1)[1,1], e(covunemp2)[1,1], e(covunemp3)[1,1], e(covunemp4)[1,1])

	mat C= (C \ t)
end 


*freq, 4 emp cats, 4 wage stats
mat C= J(1,8,.)


//Same groups as exhbit 1b
ex3stats

//FEMALE AND URBAN AND YOUTH
foreach var in female {
	foreach i of numlist 0 1 {
		ex3stats if `var'==`i' 
	}
}

foreach var in occupcat {
foreach i of numlist 1 2 3 {
	ex3stats if `var'==`i'
}
}


foreach var in earn_feb_conq {
foreach i of numlist 1 2 3 {
	ex3stats if `var'==`i'
}
}

foreach i of numlist 0 1 {
	ex3stats if contract==`i' 
}



*Manipulate as stata dataset, cols are each group (eg men)
mat C= C[2...,1...]
mat C= C'

clear
xsvmat C, norestore


*Define ters vs uif \\ note: legacy code naming here, but harmless
g uif= _n>4

*Define type
g reach= 1 if inlist(_n, 1,5)
replace reach= 2 if inlist(_n, 2,6)
replace reach= 3 if inlist(_n, 3,7)
replace reach= 4 if inlist(_n, 4,8)


*Some juggling to get into shape for bar graph
g id=_n
reshape long C, i(id)
ren (_j C) (group coverage)
drop id 
replace coverage= coverage*100

*Label bars (groups)
lab def group 1 "All" 2 "Men" 3 "Women" 4 "Professionals" 5 "Service/Operators" 6 "Manual" 7 "Q1-2" 8 "Q3" 9 "Q4" 10 "Verbal" 11 "Written", modify
lab val group group

g supergroup= 1 if inlist(group, 1)
replace supergroup= 2 if inlist(group, 2,3)
replace supergroup= 3 if inlist(group, 4,5,6)
replace supergroup= 4 if inlist(group, 7,8,9)
replace supergroup= 7 if inlist(group, 10,11)

//Panel A
preserve 
	keep if uif==0
	reshape wide coverage, i(group) j(reach)
	graph bar (mean)  coverage1 coverage2 coverage3 coverage4, stack over(group, label(angle(45) labsize(vsmall))) over(supergroup,  relabel(1 "All" 2 "Sex" 3 "Occupation" 4 "Earnings quartile (Feb)" 5 "Contract (2017)") label(labsize(small))) nofill leg(on pos(6) row(1) order(1 "No protection" 2 "TERS only" 3 "HH grant only" 4 "Both")) bar(1, color(red%70)) bar(2, color(navy%70)) bar(3, color(purple%70)) bar(4, color(green%70)) yti("% workers on leave by each group") blabel(bar, format(%2.0f) size(small) pos(center))
	
	graph export "${cram}\Figures\ex3a_covters_v3.pdf", replace
	graph export "${cram}\Figures\ex3a_covters_v3.svg", replace

restore


//Panel B
preserve 
	keep if uif==1
	reshape wide coverage, i(group) j(reach)
	graph bar (mean)  coverage1 coverage2 coverage3 coverage4, stack over(group, label(angle(45) labsize(vsmall))) over(supergroup,  relabel(1 "All" 2 "Sex" 3 "Occupation" 4 "Earnings quartile (Feb)" 5 "Contract (2017)") label(labsize(small))) nofill leg(on pos(6) row(1) order(1 "No grant" 2 "HH CSG grant only" 3 "HH other grant only" 4 "Both")) bar(1, color(red%70)) bar(2, color(pink%70)) bar(3, color(purple%70)) bar(4, color(green%70)) yti("% job losers by each group") blabel(bar, format(%2.0f) size(small) pos(center))
	
	graph export "${cram}\Figures\ex3b_covuif_v3.pdf", replace
	graph export "${cram}\Figures\ex3b_covuif_v3.svg", replace
restore





***************************************************************
*EXHIBIT 4: WELFARE EFFECTS
***************************************************************

/*
1. Match w/ NIDS vars
2. Use lasso for selection equation
3. Use psmatch2 for reweighting of job loss sample and save weight
4. Save results for
	a. Hunger
	b. Poverty 
	c. Household income density
*/

/*

*Main income
use  "${trash}\temp.dta", clear
merge 1:1 pid using "${cram}\Data\Data\incpscores_v2.dta", keep(match)
save "${trash}\temp2.dta", replace
*/

//Prepare list of cat and continuous vars*********************

use "${cram}\Data\temp_lasso.dta", clear
vl set, categorical(20) uncertain(30) dummy

foreach var in LScon_em1pay LScon_em1hrs LScon_incchld_v LScon_hhwage LScon_hhgovt LScon_hhremitt {
	replace `var'= 0 if `var'==.
}

foreach var of varlist * {
	assert !mi(`var')
}


vl move (hhid pid) vlother
vl move (LScat*) vlcategorical
vl move (LScon_hhsizer) vlcontinuous

di "$vldummy" 
di "$vlcategorical" 
di "$vlcontinuous" 
di "$vluncertain" 

foreach var in $vlcategorical {
	di "`var' is about to be replaced"
	replace `var'= 999 if `var'==. | `var'<0
}

vl substitute ivlcategorical = i.vlcategorical
save "${trash}\temp3.dta", replace



//PROGRAM FOR LASSO************************************************

cap prog drop lassopscore
prog define lassopscore
	
	*Check that all own vars have no missings!
	foreach var in contract w6_educ_bins w6_metro urban {
		replace `var'= 999 if `var'==. | `var'<0
	}
	
	*Run Lasso
	lasso logit loss w6_age age2 w6_gender i.w6_educ_bins urban w6_metro contract $ivlcategorical $vlcontinuous [iw=w6_wgt], rseed(7192) sel(adapt)
	cap drop pscore
	predict pscore, post

	*Own score 
	cap drop psweight
	sum loss [aw=w6_wgt]  if pscore!=.
	local aveloss= r(mean)
	g psweight= pscore/(1-pscore)*(1-`aveloss')/`aveloss'*w6_wgt if loss==0
	replace psweight= w6_wgt if loss==1
	sum pscore if loss==1, de
	replace psweight= . if loss==0 & (pscore<r(p1) | pscore>r(p99))

end



//PANELS A AND B: JOB LOSS******************************
*Only empcat 1 --> 3 or 4 (not 2)

use  "${trash}\temp.dta", clear
*Decide on which job loss var to use
cap drop loss
g loss= jobloss_34

keep if w6_empcat_feb==1 & (loss==1 | inlist(w6_empcat_apr, 1))
merge 1:1 pid using "${trash}\temp3.dta", keep(master match)
*104 don't match

//Need to restore macros
vl rebuild

//Run lasso
lassopscore
ren (pscore psweight) (jobpscore jobpsweight) 
save  "${trash}\temp2.dta", replace

//Also save these estimates bc takes long to run
keep pid jobpscore jobpsweight 
save  "${cram}\Data\Data\jobpscores_v2.dta", replace

/*If just want to run graphs:
use  "${trash}\temp.dta", clear
merge 1:1 pid using "${cram}\Data\Data\jobpscores_v2.dta", keep(match) nogen
g loss= jobloss_34
save "${trash}\temp2.dta", replace
*Also to check lasso: lassocoef and lassogof
*/


//HHINCOME
use "${trash}\temp2.dta", clear

twoway (kdensity lnhhincomepc [aw= jobpsweight] if loss==1, lc($emp4 )) (kdensity lnhhincomepc [aw= jobpsweight] if loss==0, lc($emp1 )) (kdensity lnhhincomepc [aw= w6_wgt] if loss==0, lc(navy%70)), leg(on row(1) pos(6) order(1 "Job losers" 2 "Job retainers (re-weighted)" 3 "Job retainers")) yti(Density) xti("log Household income per capita (Lockdown, April)") xline(6.363 7.143)

graph export "${cram}\Figures\ex4a_jlosshhinc_v2.pdf", replace
graph export "${cram}\Figures\ex4a_jlosshhinc_v2.svg", replace





//HUNGER AND POVERTY
use "${trash}\temp2.dta", clear
svyset cluster [weight = jobpsweight], strata(stratum)
svydescribe if loss==0

*get rid of single stratum obs
bys stratum loss: egen units= count(pid) if jobpsweight!=.

** check: if this fails, take the outdated units restrictions out (we don't use svy std errors anymore)
assert units > 1

//Repeated for income so just making as prog for easier checking
cap prog drop dflpovestimates
program define dflpovestimates

syntax, mat(string)

mat `mat' = J(1,4,.) 
foreach var in w6_hhfdyn foodpov w5_foodpov ubpov w5_ubpov foodpov_wgrant ubpov_wgrant {
	svy: reg `var' if loss==1 & units>1
	mat t1= (1, _b[_cons], r(table)[5,1], r(table)[6,1])
	svy: reg `var' if loss==0 & units>1
	mat t2= (2, _b[_cons], r(table)[5,1], r(table)[6,1])
	svy: reg `var' loss if units>1
	mat t3= (3, _b[loss],  r(table)[5,1], r(table)[6,1]) 
	mat `mat'  = (`mat'  \ t1 \ t2 \ t3)
}
mat `mat' = `mat'[2..., 1...]

*Naive estimates
svyset cluster [weight = w6_wgt], strata(stratum)
foreach var in foodpov ubpov {
	svy: reg `var' if loss==1 & units>1
	mat t1= (1, _b[_cons], r(table)[5,1], r(table)[6,1])
	svy: reg `var' if loss==0 & units>1
	mat t2= (2, _b[_cons], r(table)[5,1], r(table)[6,1])
	svy: reg `var' loss if units>1
	mat t3= (3, _b[loss],  r(table)[5,1], r(table)[6,1]) 
	mat `mat' = (`mat'  \ t1 \ t2 \ t3)
}

*Store speculative estimates: grants and naive

// let's make sure we have the right structure in mind here:
assert rowsof(`mat') == 27

mat `mat'b= `mat'[16..27,1...]
svy: mean w5_hhdependents if loss==1
mat t= (.,r(table)[1,1],.,.)
mat `mat'b= (`mat'b \ t)
mat coln `mat'b= "Loss?" "b" "lb" "ub"
mat rown `mat'b= "Food w/g" "Food w/g" "Food w/g" "ub w/g" "ub w/g" "ub w/g" "food naive" "food naive" "food naive" "ub naive" "ub naive" "ub naive" "Ave loss dependents"

local numrows= rowsof(`mat')

//Graph poverty and job loss
	clear 
	svmat `mat'
	g id= _n
	ren (`mat'1 `mat'2 `mat'3 `mat'4)(loss b lb ub)
	g y=.
	forval i= 3(3)`numrows' {
		replace y= `i'/3 if inrange(id, `i'-2,`i') 
	}

	*Create gaps for bars
	g orderid= id
	replace orderid= id+1 if inrange(id,4,6)
	replace orderid= id-1 if inrange(id,10,12)

	*Adjust to percentages
	foreach var in b lb ub {
		replace `var'= round(100*`var')
	}
end

//Store totals
total w6_wgt if loss==1
local loss: di %3.2f r(table)[1,1]/1e6
local noloss 
total w6_wgt if loss==0
local noloss : di %3.2f r(table)[1,1]/1e6

//Run estimates
dflpovestimates, mat(D1)

//Main plot for poverty
	twoway (bar b orderid if loss==1, col($emp4 )) ///
			(bar b orderid if loss==2, col($emp1 )) ///
			(bar b orderid if loss==3, col(pink%50 )) ///
			/*(rcap ub lb orderid, col(gray%70))*/ ///
			(scatter b orderid, msym(none) mlab(b) mlabpos(11)) ///
			if inlist(y,2,4), ///
			legend(row(1) order(1 "Job losers (`loss' million)" 2 "Job retainers (`noloss' million - re-weighted)" 3 "Difference") pos(6)) ///
			xlabel( 6 "StatsSA food poverty line" 10 "StatsSA upper poverty line", noticks) ///
			scheme(plotplain) xtitle("Welfare measure") ytitle("Pct. in poverty") yscale(range(0 70)) ylabel(0(20)90) 

	graph export "${cram}\Figures\ex4b_jlosspov_v2.pdf", replace
	graph export "${cram}\Figures\ex4b_jlosspov_v2.svg", replace

	
//Plot for matched sample
	*Take 2020 - 2017 for each pov estimate 
	bys loss (y): g bdiff= b[_n]-b[_n+1]
	replace bdiff= b if y==1

	twoway  (bar bdiff orderid if loss==1, col($emp4 )) ///
			(bar bdiff orderid if loss==2, col($emp1 )) ///
			(bar bdiff orderid if loss==3, col(pink%50 )) ///
			(scatter bdiff orderid, msym(none) mlab(bdiff) mlabpos(11)) ///
			if inlist(y,1,2,4), ///
			legend(row(1) order(1 "Job losers (`loss' million)" 2 "Job retainers (`noloss' million - re-weighted)" 3 "Difference") pos(6)) ///
			xlabel(2 "Could not afford food" 6 "Food poverty line (DiD)" 10 "Upper poverty line (DiD)", noticks) ///
			scheme(plotplain) xtitle("Welfare measure") ytitle("Pct. in poverty") yscale(range(0 60)) ylabel(0(20)60) 
			
	graph export "${cram}\Figures\ex4appc_jlossMDiD_v2.pdf", replace
	graph export "${cram}\Figures\ex4appc_jlossMDiD_v2.svg", replace




//DIAGNOSTICS
// NOTE: this graph is slightly incorrect as of the 15 June 2020 version of the working paper. The code is corrected in our current analysis. Qualitative conclusions remain unchanged.
//Overlap of propensity score
use "${trash}\temp2.dta", clear
	egen psbin= cut(jobpscore), at(0(.05)1)
	drop if psbin==.
	g treated= 1 if loss==1 & jobpsweight!=.
	replace treated= 0 if loss==0 & jobpsweight!=.
	replace treated= -1 if loss==0 & jobpsweight==. 
	collapse (count) freq=pid, by(psbin treated)
	bys psbin (treated): replace freq= freq[1]+freq[2] if _n==1
	replace freq=-freq if treated<1 
	twoway  (bar freq psbin if treated==1, barw(.05) col($emp4 )) (bar freq psbin if treated==0, barw(.05) col($emp1 )) (bar freq psbin if treated==-1, barw(.05) fcolor(none) lc(navy%70)), leg(row(1) pos(6) order(1 "Job loss sample" 2 "No job loss - comparison sample" 3 "No job loss - full sample")) yti("Number of observations") xtitle("Probability of job loss (propensity score)")
	
	graph export "${cram}\Figures\ex4appa_pscoreoverlap_v2.pdf", replace
	graph export "${cram}\Figures\ex4appa_pscoreoverlap_v2.svg", replace

	

//Repeat whole exercise, excluding w5_hhincome.
*The plot density of w5_hhincome for weighted job retain vs jobloss
use "${trash}\temp2.dta", clear

// moving also LScon_hhincome LScon_hhwage LScon_hhgovt to vlother
drop jobpscore jobpsweight
vl move (LScon_hhincomepc LScon_hhincome LScon_hhwage LScon_hhgovt) vlother

*Run Lasso
lassopscore
ren (pscore psweight)(jobrob_pscore jobrob_psweight)

*Now run (from here for preloaded)
cap g lnw5_hhincomepc= ln(w5_hhincomepc )

twoway (kdensity lnw5_hhincomepc [aw= jobrob_psweight] if loss==1, lc($emp4 )) (kdensity lnw5_hhincomepc [aw= jobrob_psweight] if loss==0, lc($emp1 )) (kdensity lnw5_hhincomepc [aw= w6_wgt] if loss==0, lc(navy%70)), leg(on row(1) pos(6) order(1 "Job losers" 2 "Job retainers (re-weighted)" 3 "Job retainers")) yti(Density) xti("log Household income per capita (2017)")  xline(6.363 7.143)

graph export "${cram}\Figures\ex4appb_jlossinctest_v2.pdf", replace
graph export "${cram}\Figures\ex4appb_jlossinctest_v2.svg", replace


*Save data
keep pid jobrob_pscore jobrob_psweight 
merge 1:1 pid using "${cram}\Data\Data\jobpscores_v2.dta",
drop _merge
save  "${cram}\Data\Data\jobpscores_v2.dta", replace



//PANELS C AND D: HH INCOME LOSS******************************


use  "${trash}\temp.dta", clear
*Decide on which income loss var to use
cap drop loss
g loss= w6_hhincloss_clean

merge 1:1 pid using "${trash}\temp3.dta", keep(master match)
*305 don't match

//Need to restore macros
vl rebuild

*Run Lasso
lassopscore
ren (pscore psweight) (incpscore incpsweight) 
save  "${trash}\temp2.dta", replace

//Also save these estimates bc takes long to run
keep pid incpscore incpsweight 
save  "${cram}\Data\Data\incpscores_v3.dta", replace

/*If just want to run graphs:
use  "${trash}\temp.dta", clear
merge 1:1 pid using "${cram}\Data\Data\incpscores_v3.dta", keep(match) nogen
g loss= w6_hhincloss_clean
save "${trash}\temp2.dta", replace
*/


//hhincomepc
use "${trash}\temp2.dta", clear
twoway (kdensity lnhhincomepc [aw= incpsweight] if loss==1, lc($emp4 )) (kdensity lnhhincomepc [aw= incpsweight] if loss==0, lc($emp1 )) (kdensity lnhhincomepc [aw= w6_wgt] if loss==0, lc(navy%70)), leg(on row(1) pos(6) order(1 "Main income loss" 2 "No main income loss (re-weighted)" 3 "No main income loss")) yti(Density) xti("log Household income per capita (Lockdown, April)") xline(6.363 7.143)

graph export "${cram}\Figures\ex4c_inclosshhinc_v3.pdf", replace
graph export "${cram}\Figures\ex4c_inclosshhinc_v3.svg", replace



//HUNGER AND POVERTY
use "${trash}\temp2.dta", clear
svyset cluster [weight = incpsweight], strata(stratum)
svydescribe if loss==0

*get rid of single stratum obs
bys stratum loss: egen units= count(pid) if incpsweight!=.

assert units > 1

//Store totals
total w6_wgt if loss==1
local loss: di %3.2f r(table)[1,1]/1e6
local noloss 
total w6_wgt if loss==0
local noloss : di %3.2f r(table)[1,1]/1e6

//Run earlier program
dflpovestimates, mat(D2)

	twoway (bar b orderid if loss==1, col($emp4 )) ///
			(bar b orderid if loss==2, col($emp1 )) ///
			(bar b orderid if loss==3, col(pink%50 )) ///
			/*(rcap ub lb orderid, col(gray%70))*/ ///
			(scatter b orderid, msym(none) mlab(b) mlabpos(11)) ///
			if inlist(y,2,4), ///
			legend(row(1) order(1 "HH income loss (`loss' mill.)" 2 "No HH income loss (`noloss' mill. - re-weighted)" 3 "Difference") pos(6)) ///
			xlabel( 6 "StatsSA food poverty line" 10 "StatsSA upper poverty line", noticks) ///
			scheme(plotplain) xtitle("Welfare measure") ytitle("Pct. in poverty") yscale(range(0 80)) ylabel(0(20)80) 

	graph export "${cram}\Figures\ex4d_inclosspov_v3.pdf", replace
	graph export "${cram}\Figures\ex4d_inclosspov_v3.svg", replace

	
//Plot for matched sample
	*Take 2020 - 2017 for each pov estimate 
	bys loss (y): g bdiff= b[_n]-b[_n+1]
	replace bdiff= b if y==1

	twoway  (bar bdiff orderid if loss==1, col($emp4 )) ///
			(bar bdiff orderid if loss==2, col($emp1 )) ///
			(bar bdiff orderid if loss==3, col(pink%50 )) ///
			(scatter bdiff orderid, msym(none) mlab(bdiff) mlabpos(11)) ///
			if inlist(y,1,2,4), ///
			legend(row(1) order(1 "HH income loss (`loss' million)" 2 "No HH income (`noloss' million - re-weighted)" 3 "Difference") pos(6)) ///
			xlabel(2 "Could not afford food" 6 "Food poverty line (DiD)" 10 "Upper poverty line (DiD)", noticks) ///
			scheme(plotplain) xtitle("Welfare measure") ytitle("Pct. in poverty") yscale(range(0 70)) ylabel(0(20)70) 
			
	graph export "${cram}\Figures\ex4appc_inclossMDiD_v3.pdf", replace
	graph export "${cram}\Figures\ex4appc_inclossMDiD_v3.svg", replace






//Diagnostics
*Overlap of propensity score
// NOTE: this graph is slightly incorrect as of the 15 June 2020 version of the working paper. The code is corrected in our current analysis. Qualitative conclusions remain unchanged.
use "${trash}\temp2.dta", clear
	egen psbin= cut(incpscore), at(0(.05)1)
	drop if psbin==.
	g treated= 1 if loss==1 & incpsweight!=.
	replace treated= 0 if loss==0 & incpsweight!=.
	replace treated= -1 if loss==0 & incpsweight==. 
	collapse (count) freq=pid, by(psbin treated)
	bys psbin (treated): replace freq= freq[1]+freq[2] if _n==1
	replace freq=-freq if treated<1 
	twoway (bar freq psbin if treated==1, barw(.05) col($emp4 )) (bar freq psbin if treated==0, barw(.05) col($emp1 )) (bar freq psbin if treated==-1, barw(.05) fcolor(none) lc(navy%70)), leg(row(1) pos(6) order(1 "Income loss sample" 2 "No income loss - comparison sample" 3 "No income loss - full sample") size(vsmall)) yti("Number of observations") xtitle("Probability of main income loss (propensity score)")
	
	graph export "${cram}\Figures\ex4appc_incpscoreoverlap_v3.pdf", replace
	graph export "${cram}\Figures\ex4appc_incpscoreoverlap_v3.svg", replace






//Repeat whole exercise, excluding w5_hhincome.
*The plot density of w5_hhincome for weighted job retain vs jobloss
use "${trash}\temp2.dta", clear

// adding a vl rebuild command 
vl rebuild

drop incpscore incpsweight
vl move (LScon_hhincomepc LScon_hhincome LScon_hhwage LScon_hhgovt) vlother

*Run Lasso
lassopscore
ren (pscore psweight) (incrob_pscore incrob_psweight) 


cap g lnw5_hhincome= ln(w5_hhincomepc)

twoway (kdensity lnw5_hhincome [aw= incrob_psweight] if loss==1, lc($emp4 )) (kdensity lnw5_hhincome [aw= incrob_psweight] if loss==0, lc($emp1 )) (kdensity lnw5_hhincome [aw= w6_wgt] if loss==0, lc(navy%70)), leg(on row(1) pos(6) order(1 "Income loss" 2 "No income loss (re-weighted)" 3 "No income loss")) yti(Density) xti("log Household income per capita (2017)") xline(6.363 7.143)

graph export "${cram}\Figures\ex4appd_inclossinctest_v3.pdf", replace
graph export "${cram}\Figures\ex4appd_inclossinctest_v3.svg", replace


*Save data
keep pid incrob_pscore incrob_psweight 
merge 1:1 pid using "${cram}\Data\Data\incpscores_v3.dta",
drop _merge
save  "${cram}\Data\Data\incpscores_v3.dta", replace



***************************************************************
*DATA APPENDIX
***************************************************************

use "${trash}\temp.dta", clear

foreach var in w5_hhincome w5_hhq_inc w6_hhincome w6_hhincome_imp {
	g ln`var'= ln(`var')
}

//PANEL A
twoway (kdensity lnw5_hhq_inc, lc(navy) lp(solid))(kdensity lnw5_hhincome , lc(navy) lp(dash))(kdensity lnw6_hhincome, lc(red%70) lp(solid))(kdensity lnw6_hhincome_imp, lc(red%70) lp(dash)), leg(on order(1 "NIDS, one-shot" 2 "NIDS, derived" 3 "CRAM, one-shot raw" 4 "CRAM one-shot imputed") pos(6) row(2)) ti("Quality of household income variable in CRAM") xscale(range(4 15)) xlabel(4(3)13) xti("Log household income") yti(Density)

graph export "${cram}\Figures\exDataApp_hhinc_v2.pdf", replace
graph export "${cram}\Figures\exDataApp_hhinc_v2.svg", replace




//PANEL B -- hhsizer
use "${trash}\temp.dta", clear
ren (w6_hhsizer) (hhsizer6)
ren (w5_hhsizer) (hhsizer5)
keep hhsizer? pid w6_fwgt
reshape long hhsizer, i(pid) j(wave)
label val wave

replace w6_fwgt= w6_fwgt/1e6
replace hhsizer= . if hhsizer<=0 | hhsizer>10
graph bar (sum) w6_fwgt, over(wave) asyvar over(hhsizer) bar(1, color(navy%70)) bar(2, color(red%70)) leg(on pos(6) row(1) order(1 "NIDS" 2 "CRAM")) ti("Household size as reported by individuals by wave") yti("Total individuals (millions)")

graph export "${cram}\Figures\exDataApp_hhsizer_v2.pdf", replace
graph export "${cram}\Figures\exDataApp_hhsizer_v2.svg", replace



//PANEL C: VARIANCE DECOMP
use "${trash}\temp.dta", clear

foreach var in w6_hhincome w6_hhincome_imp w6_hhincome_cl {
	g ln`var'pc= ln(`var'/w6_hhsizer)
}
bys w6_guess_hhid : egen hhcount= count(pid)
g shared= 1 if inrange(hhcount, 2,10)

mat F= J(5,1,.)
foreach y in lnw6_hhincomepc lnw6_hhincome_clpc lnw6_hhincome_imppc {
	cap drop `y'_*
	
	bys w6_guess_hhid: egen `y'_mhh= mean(`y') if shared==1
	g `y'_wn= `y' -  `y'_mhh if shared==1
	
	summ `y' if shared==1
	mat t= (r(Var))
	
	summ `y'_wn if shared==1
	mat t= (t \ r(Var))
	
	summ `y'_mhh if shared==1
	mat t= (t \ r(Var))
	
	corr `y'_mhh `y'_wn if shared==1
	mat t= (t \ 2*r(rho) \ r(N))
	
	mat F= (F, t)
}
mat F= F[1...,2...]
mat rown F= "Total" "W/in HH" "B/n HH" "2*Cov" "Obs"
mat coln F= "One shot" "No outliers" "Imputed" 
mat list F

esttab matrix(F) using "${cram}\Figures\exDataApp_vardecomp_v2.xls", replace label nomtitle




