* project: "The labour market and poverty impacts of Covid-19 in South Africa" (15 July 2020 Version)
* authors: Ronak Jain - rjain@g.harvard.edu, Joshua Budlender - jbudlender@umass.edu, Rocco Zizzamia - rocco.zizzamia@qeh.ox.ac.uk & Ihsaan Bassier - ibassier@umass.edu (randomised author order).
* link: https://cramsurvey.org/wp-content/uploads/2020/07/Jain-The-labour-market-and-poverty-impacts.pdf
********************************************************************************

* this file cleans our NIDS Wave 5 and NIDS-CRAM merged panel, creating the main variables we use in our analysis

* it is run from "5.5 Jain_NIDSw5_NIDS-CRAM_mainanalysis_w1.do"

* note: this creates some extra variables no longer used in our analysis, or used in our post 15 June analysis

* this file last updated on 21 July 2020

********************************************************************************
********************************************************************************


* pre-check
drop if mi(pid)	// my understanding is that these are wholly deceased households
assert w6_outcome != 1 if mi(w5_wgt)
drop if mi(w5_wgt)	// these should be dead individuals and non-residents from wave 5


//Get rid of refusal and don't know
foreach var in w6_eminc_feb w6_eminc_feb_brac w6_emdayinc_apr w6_emwkinc_apr w6_emwkinc_apr_brac w6_em2wksinc_apr w6_em2wksinc_apr_brac w6_eminc_apr w6_eminc_apr_brac  w6_emsinc_apr w6_emsinc_apr_brac w6_emdays_apr w6_emdays_feb {
	recode `var' (-9/-1=.)
}
	

********************************************************************************
*** Earnings
********************************************************************************

* bracket vars check:
foreach var in w6_eminc_feb_brac w6_eminc_apr_brac w6_emwkinc_apr_brac w6_em2wksinc_apr_brac w6_emsinc_apr_brac {
	assert inlist(`var', 1,2,3,4,5,6,.)
}

//FEBRUARY EARNINGS

//February brackets: 356 replacements
		
	g w6_eminc_feb_imp= w6_eminc_feb
	replace w6_eminc_feb_imp = 0 if w6_eminc_feb_brac ==1
	
	sum w6_eminc_feb if w6_eminc_feb >0 & w6_eminc_feb <3000, d
	replace w6_eminc_feb_imp = r(p50) if w6_eminc_feb_brac ==2
	
	sum w6_eminc_feb if w6_eminc_feb >=3000 & w6_eminc_feb <=6000, d 
	replace w6_eminc_feb_imp = r(p50) if w6_eminc_feb_brac ==3
	
	sum w6_eminc_feb if w6_eminc_feb >6000 & w6_eminc_feb <=12000, d 
	replace w6_eminc_feb_imp = r(p50) if w6_eminc_feb_brac ==4
	
	sum w6_eminc_feb if w6_eminc_feb >12000 & w6_eminc_feb <=24000, d 
	replace w6_eminc_feb_imp = r(p50) if w6_eminc_feb_brac ==5
	
	replace w6_eminc_feb_imp = 2*24000 if w6_eminc_feb_brac ==6

	
//Feb tot wage
	gen w6_totwage_feb = w6_eminc_feb_imp
	replace w6_totwage_feb =. if w6_totwage_feb >100000
	
//APRIL EARNINGS (948 non missing)
	*Also need to convert all figures to a monthly figure
	
// Monthly earnings 
	local mbrac1 ERROR
	local mbrac2 1,3000
	local mbrac3 3001,6000
	local mbrac4 6001,12000
	local mbrac5 12001,24000
	local mbrac6 ERROR
	local mbracend 24000
	
	g w6_eminc_apr_imp= w6_eminc_apr
	replace w6_eminc_apr_imp = 0 if w6_eminc_apr_brac ==1
	forval i = 2/5 {
		su w6_eminc_apr if inrange(w6_eminc_apr, `mbrac`i''), d
		replace w6_eminc_apr_imp = r(p50) if w6_eminc_apr_brac == `i'
	}
	replace w6_eminc_apr_imp = 2*`mbracend' if w6_eminc_apr_brac ==6
	
	
// Weekly earnings (130 non missing)
*(Label is wrong. Refer to questionnaire.)
	local wbrac1 ERROR
	local wbrac2 1,700
	local wbrac3 701,1400
	local wbrac4 1401,2800
	local wbrac5 2801,5500
	local wbrac6 ERROR
	local wbracend 5500

	g w6_emwkinc_apr_imp= w6_emwkinc_apr
	replace w6_emwkinc_apr_imp = 0 if w6_emwkinc_apr_brac ==1
	forval i = 2/5 {
		su w6_emwkinc_apr if inrange(w6_emwkinc_apr, `wbrac`i''), d
		replace w6_emwkinc_apr_imp = r(p50) if w6_emwkinc_apr_brac == `i'
	}
	replace w6_emwkinc_apr_imp = 2*`wbracend' if w6_emwkinc_apr_brac ==6
	
	
// Fortnightly earnings (69 non missing)
	local fbrac1 ERROR
	local fbrac2 1,1400
	local fbrac3 1401,2800
	local fbrac4 2801,5500
	local fbrac5 5501,11000
	local fbrac6 ERROR
	local fbracend 11000
	
	g w6_em2wksinc_apr_imp= w6_em2wksinc_apr
	replace w6_em2wksinc_apr_imp = 0 if w6_em2wksinc_apr_brac ==1
	forval i = 2/5 {
		su w6_em2wksinc_apr if inrange(w6_em2wksinc_apr, `fbrac`i''), d
		replace w6_em2wksinc_apr_imp = r(p50) if w6_em2wksinc_apr_brac == `i'
	}
	replace w6_em2wksinc_apr_imp = 2*`fbracend' if w6_em2wksinc_apr_brac ==6
	

//Convert all earnings to monthly 
	* Multipling up to monthly totals. Just check whether the frequency var works as a flag for this replacement:
	assert mi(w6_eminc_apr) if inlist(w6_empay_freq,1,2,3)	
	assert w6_empay_freq == 1 if !mi(w6_emdayinc_apr)
	assert w6_empay_freq == 2 if !mi(w6_emwkinc_apr)
	assert w6_empay_freq == 3 if !mi(w6_em2wksinc_apr)	// all good
	

	** To check these for outliers, lets create new variables, check them, and then replace afterwards
	
	* just to confirm that we shouldn't be using embusdays_apr for daily wage, confirm that those who report self-emp or "run a business" do not report daily earnings:
	assert mi(w6_emdayinc_apr) if inlist(w6_emtyp, 3,4)
	
	gen temp_day_monthly = w6_emdayinc_apr*w6_emdays_apr*4.33 if w6_emdays_apr >= 0 
	gen temp_wk_monthly = w6_emwkinc_apr_imp*4.33
	gen temp_2wks_monthly = w6_em2wksinc_apr_imp*2.17
	
	
	* Sub in imputed daily, weekly and 2-weekly earnings
	replace w6_eminc_apr_imp = temp_day_monthly if mi(w6_eminc_apr_imp)
	replace w6_eminc_apr_imp = temp_wk_monthly if mi(w6_eminc_apr_imp)
	replace w6_eminc_apr_imp = temp_2wks_monthly if mi(w6_eminc_apr_imp)
	
		drop temp_day_monthly temp_wk_monthly temp_2wks_monthly

	
//Apr profits (207 non-miss)
	g w6_emsinc_apr_imp= w6_emsinc_apr 
	replace w6_emsinc_apr_imp = 0 if w6_emsinc_apr_brac ==1
	
	sum w6_emsinc_apr if w6_emsinc_apr >0 & w6_emsinc_apr <3000, d
	replace w6_emsinc_apr_imp = r(p50) if w6_emsinc_apr_brac ==2
	sum w6_emsinc_apr if w6_emsinc_apr >=3000 & w6_emsinc_apr<=6000, d
	replace w6_emsinc_apr_imp = r(p50) if w6_emsinc_apr_brac ==3
	sum w6_emsinc_apr if w6_emsinc_apr >6000 & w6_emsinc_apr<=12000, d
	replace w6_emsinc_apr_imp = r(p50) if w6_emsinc_apr_brac ==4
	sum w6_emsinc_apr if w6_emsinc_apr>12000 & w6_emsinc_apr<=24000, d
	replace w6_emsinc_apr_imp = r(p50) if w6_emsinc_apr_brac ==5	
	replace w6_emsinc_apr_imp = 2*24000 if w6_emsinc_apr_brac ==6
	
	
	
//April totwage
	egen w6_totwage_apr = rsum(w6_emsinc_apr_imp w6_eminc_apr_imp), missing
	replace w6_totwage_apr =. if w6_totwage_apr >100000 // Note: Find a better way of trimming outliers. 4 set to missing.

	
//MISC
	*Earnings quintiles 
	xtile w6_earn_feb_5t = w6_totwage_feb if w6_totwage_feb >0 & w6_totwage_feb!=. [aw=w6_wgt], n(5)
	xtile w6_earn_apr_5t = w6_totwage_apr if w6_totwage_apr >0 & w6_totwage_apr!=. [aw=w6_wgt], n(5)
	
//NIDS WAVE 5 TOT WAGE
	egen w5_totwage =rsum(w5_fwag w5_cwag w5_swag w5_help w5_prof w5_extr), missing 
	
********************************************************************************
*** Employment status
********************************************************************************

//Clean up days var
g w6_emdays_feb_imp= w6_emdays_feb
g w6_emdays_apr_imp= w6_emdays_apr

//just confirm that w6_embusdays_apr only exists for self-employed and business owners
assert mi( w6_embusdays_apr) if !inlist(w6_emtyp,3,4)

replace w6_emdays_apr_imp= w6_embusdays_apr if w6_emdays_apr_imp==. & w6_embusdays_apr>=0

lab def w6_empcat 1 `""Working": days>0"' 2 `""Paid leave": days=0,wage>0"' 3 `""Unpaid leave": emp/emreturn,days=0,wage=0"' 4 `""Not employed": noemp,days=0,wage=0"', modify


//Same for feb and april (prioritize comparibility)
foreach mo in feb apr {
	
	*some checks before we get going
	assert w6_emdays_`mo'_imp >= 0
	assert w6_totwage_`mo' >= 0
	
	cap drop w6_empcat_`mo'
	g w6_empcat_`mo'= .
	
	*1 - days>0
	replace w6_empcat_`mo'= 1 if (w6_emdays_`mo'_imp>0 & w6_emdays_`mo'_imp!=.)
	
	*2 - days==0, wage>0
	replace w6_empcat_`mo'= 2 if (w6_emdays_`mo'_imp==0 | w6_emdays_`mo'_imp==.) ///
	& (w6_totwage_`mo'>0 & w6_totwage_`mo'!=.)
	
	*3 - emp, days==0, wage==0 ;; also "no i'm emp", wage==0, hr==0
	replace w6_empcat_`mo'= 3 if (w6_em_`mo'==1 | w6_emany_`mo'==1 | w6_ems_`mo'==1) ///
	& (w6_emdays_`mo'_imp==0 | w6_emdays_`mo'_imp==.)  ///
	& (w6_totwage_`mo'==0 | w6_totwage_`mo'==.)
	
	replace w6_empcat_`mo'= 3 if (w6_em_`mo' ==2 & w6_emany_`mo'==2 & w6_ems_`mo' == 2) ///
	& (w6_emdays_`mo'_imp==0 | w6_emdays_`mo'_imp==.) ///
	& (w6_totwage_`mo'==0 | w6_totwage_`mo'==.)
	
	*4 - unemp, wage==0, hr==0
	replace w6_empcat_`mo'= 4 if (w6_em_`mo'==2 & w6_emany_`mo'==2 & w6_ems_`mo'==3) ///
	& (w6_emdays_`mo'_imp==0 | w6_emdays_`mo'_imp==.) ///
	& (w6_totwage_`mo'==0 | w6_totwage_`mo'==.)
	
	lab val w6_empcat_`mo' w6_empcat
}


*Specific adjustment: Those who earn daily wage in april and say emp but no days. Assign cat 2. (2 changes)
replace w6_empcat_apr= 2 if (w6_em_apr==1 | w6_emany_apr==1 | w6_ems_apr==1) & (w6_emdays_apr==.) & (w6_emdayinc_apr !=.)

*Specific adjustment: Set emp==3 if return job + reason=lockdown (no wage, no hrs) (306 adjustments...)
* restrict changes to when w6_empcat_apr==4 or w6_empcat_apr==., and expanding w6_emabs_apr reasons (I only exclude "studying" and "poor health") (now only 117 real changes)
replace w6_empcat_apr= 3 if inlist(w6_emabs_apr,1,2,4,5,6,7) & w6_emreturn==1 & inlist(w6_empcat_apr, 4,.)

* set Feb pensioners (who are missing details in Apr) to category 4 as NEA. 297 changes, means we have empcat for almost everyone, also logically consistent
assert mi(w6_empcat_feb) & mi(w6_empcat_feb) if w6_em_feb == 3
replace w6_empcat_feb = 4 if w6_em_feb == 3
replace w6_empcat_apr = 4 if w6_em_feb == 3

* check
assert mi(w6_empcat_feb) & mi(w6_empcat_feb) if w6_outcome != 1
	
	
********************************************************************************
*** Deflating
********************************************************************************


recode w6_hhinc (-9/-1 = .)
rename w6_hhinc w6_hhincome

	
*** NIDS-CRAM 
*According to StatsSA, basically no inflation over feb to april 
	foreach var in w6_hhincome w6_totwage_apr w6_totwage_feb w6_eminc_feb w6_eminc_feb_imp w6_eminc_apr w6_eminc_apr_imp w6_emsinc_apr w6_emsinc_apr_imp w6_emwkinc_apr w6_em2wksinc_apr w6_emdayinc_apr {
	replace `var' = `var'*w6_deflator
	}



*** NIDS. 
		foreach var in w5_hhincome w5_hhq_inc  w5_expenditure w5_expf w5_fwag w5_cwag w5_swag w5_hhgovt w5_a_incdis_v w5_p_incdis_v  w5_a_incchld_v w5_p_incchld_v  w5_a_incfos_v w5_p_incfos_v w5_a_inccare_v w5_p_inccare_v w5_a_incgovpen_v w5_p_incgovpen_v  w5_hhwage  w5_hhgovt w5_hhremitt w5_hhagric w5_hhinvest w5_hhother w5_totwage {
		replace `var' = `var'*w5_deflator
		}

gen w6_totwage_apr_ln = log(w6_totwage_apr)
gen w6_totwage_feb_ln = log(w6_totwage_feb)

*===============================================================================
***	Cleaning and harmonising variables between NIDS and NIDS-CRAM
*===============================================================================


***	dropping "refused" and "don't know"s. 
	foreach var in _best_age_yrs _best_gen _best_race _geo2011 _prov2011 _h_watsrc _empl_stat _h_dwltyp _h_enrgelec _a_em1occ_isco_c _a_unemdc _a_em1deduif _hhsizer _hhincome { 
	recode w5`var' (-9/-2=.)
	assert w5`var' >= 0		
	}

*** Age
	rename w5_best_age_yrs w5_age
	rename w6_best_age_yrs w6_age
	recode w6_age (-9/-1=.)

*** Gender
	rename w5_best_gen w5_gender
	ren w6_best_gen w6_gender
	
*** Race 
	rename w5_best_race w5_race
	rename w6_best_race w6_race
	recode w6_race  (-8/-1=.)


	
*** Area
	rename w5_geo2011 w5_area
	recode w6_geo2011 (-8/-1=.)
	assert w6_geo2011 >= 0	
	rename w6_geo2011 w6_area
	
*** Province
	rename w5_prov2011 w5_prov
	recode w6_prov2011 (-9/-1=.) (10=.)
	assert w6_prov2011 >= 0
	drop w6_prov
	rename w6_prov2011 w6_prov
	
	
***Province Before Lockdown 
	recode w6_lvbfprov (-9/-1=.) (10=.)
	gen prov_b_lockdown = w6_prov if w6_outcome==1
	replace prov_b_lockdown = w6_lvbfprov if !mi(w6_lvbfprov)	
	lab var prov_b_lockdown "Province before lockdown (cleaned)"
	
*** Household composition	
	gen w5_child_7 = 0
		replace w5_child_7 = 1 if w5_age <7 & w5_age >=0
		bys w5_hhid: egen w5_tot_child_7 = total(w5_child_7)
	gen w5_child = 0
		replace w5_child = 1 if w5_age <18 & w5_age >=0
		bys w5_hhid: egen w5_tot_child = total(w5_child)
	gen w5_adult = 0
		replace w5_adult = 1 if w5_age >= 18 & w5_age < 60
		bys w5_hhid: egen w5_tot_adult = total(w5_adult)
	gen w5_elder = 0
		replace w5_elder = 1 if w5_age >= 60 & w5_age !=.
		bys w5_hhid: egen w5_tot_elder = total(w5_elder)	
	
	rename w6_nopres w6_hhsizer 
	replace w6_hhsizer = . if w6_hhsizer ==0  
	rename w6_nou7res w6_tot_child_7
	rename w6_nou18res w6_tot_child
	rename w6_no60res w6_tot_elder
	
	
	recode w6_hhsizer w6_tot_child w6_tot_child_7 w6_tot_elder (-9/-1=.)
	
	gen w6_tot_adult = w6_hhsizer-(w6_tot_elder+w6_tot_child)
	gen w6_childrenelders = w6_tot_elder+w6_tot_child
	
	assert w6_tot_adult >=0 if pid != 404933		
	assert w6_childrenelders <= w6_hhsizer if !mi(w6_childrenelders) & pid != 404933	 
	

	
	
*** Education 

// reorganise w5_best_edu to move NTC and NCV codes (27-35) to be represented in just one place (13-15)
assert !inrange(w5_best_edu, 33,35)
recode w5_best_edu (27 = 13) (28 = 14) (29 = 15) (30 = 13) (31 = 14) (32 = 15)

*Education Bins Wave 5
gen w5_educ_bins = .
replace w5_educ_bins = 1 if inrange(w5_best_edu, 0, 7) | w5_best_edu==25
replace w5_educ_bins = 2 if inrange(w5_best_edu, 8, 11) | inlist(w5_best_edu, 13,14,16,17)
replace w5_educ_bins = 3 if inlist(w5_best_edu, 12,15)
replace w5_educ_bins = 4 if inrange(w5_best_edu, 18,23)	



*Education Bins Wave 6

gen w6_educ_bins = .
replace w6_educ_bins = 1 if inrange(w6_edschgrd, 0, 7) |  w6_edschgrd==19
replace w6_educ_bins = 2 if inrange(w6_edschgrd, 8, 11) | inlist( w6_edschgrd, 13,14,16,17)
replace w6_educ_bins = 3 if inlist(w6_edschgrd, 12,15,18)
replace w6_educ_bins = 4 if w6_edter== 1 & inlist(w6_edschgrd, 12,15,18)
	
	
la de educ_bins 1 "Up to Primary" 2 "Up to Secondary" 3 "Matric" 4 "Tertiary", modify
lab val w5_educ_bins educ_bins
lab val w6_educ_bins educ_bins





***Occupation 
	
	*Wave 5*
	*w5 occu need to add in all the proxies, self-employment etc
	foreach var of varlist w5_a_em1occ_isco_c w5_p_em1occ_isco_c w5_a_em2occ_isco_c w5_a_emsatc_isco_c w5_a_emsothatc_isco_c w5_a_emctype_isco_c w5_a_emhtsk_isco_c {
		assert inrange(`var', 0,9) | `var' < 0 | mi(`var')
		replace `var' = . if `var' < 0
	}
	
	gen w5_occu = .
	foreach var of varlist w5_a_em1occ_isco_c w5_p_em1occ_isco_c w5_a_em2occ_isco_c w5_a_emsatc_isco_c w5_a_emsothatc_isco_c w5_a_emctype_isco_c w5_a_emhtsk_isco_c {	// order of vars is nb! prioritising self-employment over casual work
		replace w5_occu = `var' if mi(w5_occu)
	}
	lab val w5_occu w5_occ_code

	
	* Wave 6*	
	recode w6_emwrk_isco_c w6_emswrk_isco_c w6_unemwrk_isco_c (-9/-1 = .)
	gen w6_occu = .
	
	//simplifying code and make structure of industry codes clearer. without these asserts one has to check the skip-pattern anyway to make sure the code makes sense.
	assert mi(w6_emswrk_isco_c) & mi(w6_unemwrk_isco_c) if !mi(w6_emwrk_isco_c)
	replace w6_occu = w6_emwrk_isco_c 
	
	assert mi(w6_emwrk_isco_c) & mi(w6_unemwrk_isco_c) if !mi(w6_emswrk_isco_c)
	replace w6_occu = w6_emswrk_isco_c if mi(w6_occu)
	
	assert mi(w6_emwrk_isco_c) & mi(w6_emswrk_isco_c) if !mi(w6_unemwrk_isco_c)
	replace w6_occu = w6_unemwrk_isco_c if mi(w6_occu)
    
	label val w6_occu w1_nc_occ_code
	
	
	recode w6_emtyp (-9/-1=.)	

gen jobloss_234 = 0 if w6_empcat_feb==1
replace jobloss_234 = 1 if inlist(w6_empcat_apr, 2,3,4) & w6_empcat_feb==1
lab var jobloss_234 "Job loss: switched from empcat 1 to empcat 2,3 or 4"

gen jobloss_34 = 0 if w6_empcat_feb==1
replace jobloss_34 = 1 if inlist(w6_empcat_apr, 3,4) & w6_empcat_feb==1
lab var jobloss_34 "Job loss: switched from empcat 1 to empcat 3 or 4"
	

***	Reason for cessation of last work related activity
	recode w5_a_noemex (-9/-1 = .)  (7 = 1 "Child care") (3=2 "Problems with my health") (6 = 3 "Looking after sick household  member(s)")(1= 4 "I'm retired") (2 = 5  "I'm studying") ( 13 = 6 "I've tried to find job but can't get one") ( 4 5 8/12 = 7 "Other"), gen(w5_noemex)

	numlabel w5_noemex, add force
	
	
***Hours worked
	recode w5_a_em1hrs (-9/-1 = .) (120/200 = .), gen(w5_emhrs)
	lab var w5_emhrs "Average work week (Hours)"
	
* Careful to make these changes AFTER employment variables defined
	recode w6_emhrs_feb (-9/-1 = .) (19/24 = .) // Recoding implausibly large numbers to missing
	recode w6_emdays_feb (-9/-1 = .) (8/max = .) // Recoding implausibly large numbers to missing
	gen w6_emhrswk_feb = w6_emhrs_feb*w6_emdays_feb
	lab var w6_emhrswk_feb "Average work week (Hours)"
	
	gen w6_emhrswk_feb_bins = .
	replace w6_emhrswk_feb_bins = 1 if w6_emhrswk_feb >=0 & w6_emhrswk_feb<35
	replace w6_emhrswk_feb_bins = 2 if w6_emhrswk_feb >=35 & w6_emhrswk_feb<=45
	replace w6_emhrswk_feb_bins = 3 if w6_emhrswk_feb > 45 & w6_emhrswk_feb !=.
	la de w6_emhrswk_feb_bins 1 "Less than 35 hrs" 2 "Between 35-45 hrs" 3 "Over 45", modify
	lab val w6_emhrswk_feb_bins w6_emhrswk_feb_bins 

	
	recode w6_emhrs_apr (-9/-1 = .) (19/24 = .)  // Recoding implausibly large numbers to missing
	recode w6_emdays_apr (-9/-1 = .) (8/max = .)  // Recoding implausibly large numbers to missing
	gen w6_emhrswk_apr = w6_emhrs_apr*w6_emdays_apr
	lab var w6_emhrswk_apr "Average work week (Hours)"
	
	gen w6_emhrswk_apr_bins = .
	replace w6_emhrswk_apr_bins = 1 if w6_emhrswk_apr >=0 & w6_emhrswk_apr<35
	replace w6_emhrswk_apr_bins = 2 if w6_emhrswk_apr >=35 & w6_emhrswk_apr<=45
	replace w6_emhrswk_apr_bins = 3 if w6_emhrswk_apr > 45 & w6_emhrswk_apr !=.
	la de w6_emhrswk_apr_bins 1 "Less than 35 hrs" 2 "Between 35-45 hrs" 3 "Over 45", modify
	lab val w6_emhrswk_apr_bins w6_emhrswk_apr_bins 

	
	
*** Hours reduction 
	gen wkhrs_reduc = .
	replace wkhrs_reduc = w6_emhrswk_feb - w6_emhrswk_apr if w6_emhrswk_feb !=. & w6_emhrswk_apr !=.
	replace wkhrs_reduc = w6_emhrswk_feb if w6_emhrswk_feb !=. & w6_emhrswk_apr ==.
	replace wkhrs_reduc = -w6_emhrswk_apr if w6_emhrswk_feb ==. & w6_emhrswk_apr !=.		
		
	
***	Written contract / formal employment
	recode w5_a_em1contr (1=1 "Yes") (2=0 "No") (-9/-2=.), gen(w5_formal)	
	lab var w5_formal "Written employment agreement"
	
	recode w6_emcontr (1=1 "Yes") (2=0 "No") (-9/-2=.), gen(w6_formal)	
	lab var w6_formal "Written employment agreement"
	numlabel w5_formal w6_formal, add
	
	
***Payment frequency 
	recode w6_empay_freq (-8=.)
	
	
*** TERS/UIF
	*Note: The NIDS variable related to whether UIF is deducted from one's salary. This is a different concept to the CRAM question, which asks about relief through UIF.
	*Note: One will also need to think about how the w6_uneminc_uif variable fits in here. 
	recode w5_a_em1deduif  (1=1 "Yes") (2=0 "No"), gen(w5_deduif)	
	lab var w5_deduif "UIF deducted from salary"
	
	recode w6_eminc_ters (-9/-8=.) (1=1 "Yes") (2=0 "No") (3=3 "Waiting"), gen(w6_tersuif)
	assert w6_tersuif >= 0
	recode w6_eminc_ters (-9/-8=.) (1=1 "Yes") (2=0 "No") (3=.), gen(w6_tersuif_yn)

	recode w6_uneminc_uif (1=1 "Yes") (2=0 "No") (-9/-8 = .), gen(w6_rwtbenuif_yn)
	assert w6_rwtbenuif_yn >= 0
	lab var w6_rwtbenuif_yn "UIF reduced work-time benefit, April"

	
*** Registered business
	recode w5_a_emstax (1=1) (2=0) (-9/-2=.), gen(w5_bsnsstax)
	cap recode w6_emsvat (1=1) (2=0) (-9/-2=.), gen(w6_bsnsstax)


***	Employment of others in business
	recode w5_a_emsnumemp (-9=.) (6=0 "0") (1 2=1 "1-9") (3=2 "10-19") (4=3 "20-49") (5=4 "50+"), gen (w5_numempl)

	//For April 
	cap recode w6_emsnumemp (-9/-8 = .) (1=0 "0") (2 3 4 = 1 "1-9") (5 = 2 "10-19") (6=3 "20-49") (7 8 = 4 "50+"), gen (w6_numempl)
	
	//For Feb: 
	cap recode w6_emsnumemp_feb (-9/-8 = .) (1=0 "0") (2 3 4 = 1 "1-9") (5 = 2 "10-19") (6=3 "20-49") (7 8 = 4 "50+"), gen (w6_numempl_feb)
	
	
	
	
*** CSG
	 rename w6_hhincchld w6_csg_number 
	 recode w6_csg_number (-9/-3 = .) 
	 assert w6_csg_number >=0 & w6_csg_number < 20 if !mi(w6_csg_number)
	 replace w6_csg_number = 1 if w6_csg_number ==. & w6_incchld == 1  
	 
	*Note, number of csg grant recipients in a household is not recorded directly in NIDS and so has to be backed out. 
	gen w5_csg= w5_a_incchld==1
	replace w5_csg = 1 if w5_p_incchld == 1	
	bys w5_hhid: egen w5_hhcsg= max(w5_csg)
	assert !mi(w5_hhcsg)

	gen w5_csg_income= w5_a_incchld_v if w5_a_incchld_v>=0 
	replace w5_csg_income = w5_p_incchld_v if w5_p_incchld_v >=0 & !mi(w5_p_incchld_v) & mi(w5_csg_income)	
	bys w5_hhid: egen w5_hhcsg_income = total(w5_csg_income)
	assert !mi(w5_hhcsg_income) 

	gen w5_csg_number= 0 if w5_hhcsg_income==0 
	replace w5_csg_number= 1 if w5_hhcsg_income>0 & w5_hhcsg_income <= 630
	replace w5_csg_number= 2 if w5_hhcsg_income>630 & w5_hhcsg_income <= 1050 
	replace w5_csg_number= 3 if w5_hhcsg_income>1050 & w5_hhcsg_income <= 1470
	replace w5_csg_number= 4 if w5_hhcsg_income>1470 & w5_hhcsg_income <= 1890
	replace w5_csg_number= 5 if w5_hhcsg_income>1890 & w5_hhcsg_income <= 2310
	replace w5_csg_number= 6 if w5_hhcsg_income>2310 & w5_hhcsg_income!=.


***	OAPs in household
	rename w6_hhincgovpen w6_oap_number
	recode w6_oap_number (-9/-3 = .)  
	replace w6_oap_number = 1 if w6_oap_number ==. & w6_incgovpen == 1 
	 
	gen w5_oap= w5_a_incgovpen==1
	replace w5_oap = 1 if w5_p_incgovpen==1	 
	bys w5_hhid: egen w5_hhoap= max(w5_oap)
	assert !mi(w5_hhoap)
	bys w5_hhid: egen w5_oap_number= total(w5_oap)

	
***	Personal grant reciept in NIDS - yes/no
	gen w5_incgov = 0 if w5_a_incdis ==2 &  w5_a_incchld ==2 & w5_a_incfos ==2 & w5_a_inccare ==2 & w5_a_incgovpen ==2
	replace w5_incgov = 0 if w5_p_incdis ==2 &  w5_p_incchld ==2 & w5_p_incfos ==2 & w5_p_inccare ==2 & w5_p_incgovpen ==2
	replace w5_incgov = 1 if w5_a_incdis ==1 |  w5_a_incchld ==1 | w5_a_incfos ==1 | w5_a_inccare ==1 | w5_a_incgovpen ==1
	replace w5_incgov = 1 if w5_p_incdis ==1 |  w5_p_incchld ==1 | w5_p_incfos ==1 | w5_p_inccare ==1 | w5_p_incgovpen ==1

* Grant dummies
foreach var in incdis incchld incfos inccare incgovpen incwar {
	recode w5_a_`var' (-9/-1 = .) (1 = 1 "Yes") (2 = 0 "No"), gen(w5_ind_`var')
	replace w5_ind_`var' = 1 if w5_p_`var' == 1
	replace w5_ind_`var' = 0 if w5_p_`var' == 2 & mi(w5_ind_`var')
}

	
***	Personal grant reciept - CRAM
	
	recode w6_incgov (-9/-8=.) (1=1) (2=0)
	 label define w6_incgov 0 "No" 1 "Yes"
	 label val w6_incgov w6_incgov
	 recode w6_incgovtyp1 (-9/-8=.)
	 
tab w6_incgovtyp1, gen(indgrnt)
 
rename indgrnt3 w6_ind_incdis
rename indgrnt1 w6_ind_incchld 
rename indgrnt4 w6_ind_incfos 
rename indgrnt5 w6_ind_inccare  
rename indgrnt2 w6_ind_incgovpen  
rename indgrnt7 w6_ind_incwar	 
rename indgrnt6 w6_ind_incsrd 
rename indgrnt8 w6_ind_inccovid  
drop indgrnt9
	 
forval i = 2/3 {	 
	replace w6_ind_incdis = 1 if w6_incgovtyp`i' == 3
	replace w6_ind_incchld = 1  if w6_incgovtyp`i' == 1
	replace w6_ind_incfos = 1  if w6_incgovtyp`i' == 4
	replace w6_ind_inccare = 1  if w6_incgovtyp`i' == 5
	replace w6_ind_incgovpen = 1  if w6_incgovtyp`i' == 2
	replace w6_ind_incwar = 1	 if w6_incgovtyp`i' == 7
	replace w6_ind_incsrd = 1 if w6_incgovtyp`i' == 6
	replace w6_ind_inccovid = 1  if w6_incgovtyp`i' == 8
}


*** Food 
	 
	 recode w6_fdcskp (-9/-1=.)
	 recode w6_fdcyn (-9/-1=.) (1=1) (2=0)	
	 recode w6_hhfdyn (-9/-1=.) (1=1) (2=0) 
	 recode w6_fdayn (-9/-1=.) (1=1) (2=0)  

		
**creation of coverage variables

*** Create household grant receipt ***
gen w6_hhincgov = .
replace w6_hhincgov = 1 if w6_csg_number > 0 & !mi(w6_csg_number)
replace w6_hhincgov = 1 if w6_oap_number > 0 & !mi(w6_oap_number)
replace w6_hhincgov = 1 if w6_incgov == 1
replace w6_hhincgov = 0 if w6_incgov == 0 & w6_csg_number == 0 & w6_oap_number == 0
lab var w6_hhincgov "Grant receipt in household"


g w6_hhcsg= 0 if w6_csg_number==0
replace w6_hhcsg=1 if (w6_csg_number > 0 & !mi(w6_csg_number))
g w6_hhothergrant= 0 if w6_hhincgov!=.
replace w6_hhothergrant= 1 if (w6_oap_number > 0 & !mi(w6_oap_number)) | (w6_incgov==1 & w6_ind_incchld!=1)

gen cover_grnt_unemp = .
replace cover_grnt_unemp = 1 if w6_hhcsg == 0 & w6_hhothergrant == 0
replace cover_grnt_unemp = 2 if w6_hhcsg == 1 & w6_hhothergrant == 0
replace cover_grnt_unemp = 3 if w6_hhcsg == 0 & w6_hhothergrant == 1
replace cover_grnt_unemp = 4 if w6_hhcsg == 1 & w6_hhothergrant == 1

label define cover_grnt_unemp 1 "No cover" 2 "HH CSG only" 3 "HH other Grant only" 4 "Both", modify
lab val cover_grnt_unemp  cover_grnt_unemp 
lab var cover_grnt_unemp "Coverage of grants"


gen cover_grnt_ters = .
replace cover_grnt_ters = 1 if w6_tersuif_yn == 0 & w6_hhincgov == 0
replace cover_grnt_ters = 2 if w6_tersuif_yn == 1 & w6_hhincgov == 0
replace cover_grnt_ters = 3 if w6_tersuif_yn == 0 & w6_hhincgov == 1
replace cover_grnt_ters = 4 if w6_tersuif_yn == 1 & w6_hhincgov == 1

label define cover_grnt_ters 1 "No cover" 2 "TERS only" 3 "Grant only" 4 "Both"
lab val cover_grnt_ters cover_grnt_ters
lab var cover_grnt_ters "Coverage of grants and TERS"
	
		
		
//hhinc quintiles	
g w5_hhincomepc= w5_hhincome/w5_hhsizer
xtile w5_hhincomepc_q4= w5_hhincomepc [aw=w5_wgt], n(4)


*** metro & DCs

* w6_mdbdc2011 and w6_dc2011 are just recodings of each other
bys w6_dc2011 (w6_mdbdc2011): assert w6_mdbdc2011[1] == w6_mdbdc2011[_N]
bys w6_mdbdc2011  (w6_dc2011): assert w6_dc2011[1] == w6_dc2011[_N]

replace w6_dc2011 = . if w6_dc2011 < 0
replace w6_mdbdc2011 = "" if inlist(w6_mdbdc2011, "-3", "-8")

gen w6_metro = inlist(w6_dc2011, 199, 260, 299, 499, 599, 797, 798, 799)
replace w6_metro = . if mi(w6_dc2011)
lab def w6_metro 1 "Yes" 2 "No"
lab val w6_metro w6_metro
lab var w6_metro "Metro dummy"



***** Income losses


* Lost main source of income
recode w6_hhincchng (-9/-1=.) (1=1 "Yes") (2=0 "No"), gen(w6_hhincloss_main)

* Lost any source of income

// clean
forval i = 1/3 {
	replace w6_hhincdec`i' = . if w6_hhincdec`i'<0
}

// check that those saying no decrease don't then list decreases
assert !inrange(w6_hhincdec2, 1,6) & !inrange(w6_hhincdec3, 1,6) if w6_hhincdec1 == 7

gen w6_hhincloss_any = .
replace w6_hhincloss_any = 0 if w6_hhincdec1 == 7
replace w6_hhincloss_any = 1 if inrange(w6_hhincdec1, 1,5)

// when hhold had no income in feb, code as no loss of income so long as they don't list other sources of income less elsewhere
replace w6_hhincloss_any = 0 if w6_hhincdec1 == 6 & !inlist(w6_hhincdec2, 1,2,3,4,5) & !inlist(w6_hhincdec3, 1,2,3,4,5)

// condition actually holds across data anyway...
assert !inlist(w6_hhincdec2, 1,2,3,4,5) if w6_hhincdec1 == 6


// 2 replacements
replace w6_hhincloss_any = 0 if mi(w6_hhincdec1) & w6_hhincdec2 == 7 & mi(w6_hhincdec3)

lab def w6_hhincloss_any 1 "Yes" 0 "No"
lab val w6_hhincloss_any w6_hhincloss_any
lab var w6_hhincloss_any "Household lost any source of income"



*****Otjer late additions: 


//Number of dependents
g earnflag= (w5_totwage>0 & w5_totwage!=.)
bys w5_hhid: egen hhnumearners= total(earnflag)
asser hhnumearners!=. & w5_hhsizer!=.

g w5_hhdependents= w5_hhsizer/hhnumearners
assert w5_hhdependents!=. if hhnumearners!=0 


//Hunger (missing num days goes missing)
g w6_fdcyn_imp= w6_fdcyn
replace w6_fdcyn_imp= w6_fdcskp/5 if w6_fdcyn_imp==1

g w6_fdayn_imp= w6_fdayn 
replace w6_fdayn_imp= w6_fdaskp/5 if w6_fdayn_imp & w6_fdaskp>0




*******************************************************************************
//Cleaned HH income var
// 1. Income lower bound
*===============================================================================
replace w6_hhincome=0 if inrange(w6_hhincome,0,2) 
* classifying SRD as COVID R350 - seems reasonable

*cleaning tot grants per hh - reducing number of grants where total number of grants exceeds total number of eligible recipients in hh
// Note: This is not necessarily a correction which reduces noise: People are just as likely to misreport the number of elderly/children as they are to misreport the number of CSGs/OAPs
*csg
count if w6_csg_number > w6_tot_child
gen w6_csg_number_clean = w6_csg_number
replace w6_csg_number_clean = w6_tot_child if w6_csg_number > w6_tot_child & w6_csg_number !=.	// 558 replacements, wow

*oap
count if w6_oap_number > w6_tot_elder 
gen w6_oap_number_clean = w6_oap_number
replace w6_oap_number_clean = w6_tot_elder if w6_oap_number > w6_tot_elder & w6_oap_number !=.	// 296 changes

	*lower bounds for income = grants in the household + reported labour earnings + personal grant receipt
	// First, create these income items
	gen w6_csg_inc = w6_csg_number*440
	gen w6_oap_inc = w6_oap_number*1860
	gen w6_csg_inc_cl = w6_csg_number_clean*440
	gen w6_oap_inc_cl = w6_oap_number_clean*1860
	gen w6_dg_inc = 1860 if w6_ind_incdis == 1
	gen w6_fcg_inc = 1080 if w6_ind_incfos == 1
	gen w6_cdg_inc = 1860 if w6_ind_inccare == 1
	gen w6_srdg_inc = 350 if w6_ind_inccovid ==1 | w6_ind_incsrd == 1
	
	// Second, sum these into a hh_inc lower bound 
	*Original hh level csg and oap vars
	egen w6_hhincome_lb =     rsum(w6_csg_inc    w6_oap_inc    w6_dg_inc w6_fcg_inc w6_cdg_inc w6_srdg_inc w6_totwage_apr), missing
	
	*Cleaned hh level csg and oap vars
	egen w6_hhincome_lb_cl =  rsum(w6_csg_inc_cl w6_oap_inc_cl w6_dg_inc w6_fcg_inc w6_cdg_inc w6_srdg_inc w6_totwage_apr), missing
	

	
// 2. Outlier detection 
*===============================================================================
	
	// Using bacon (https://journals.sagepub.com/doi/pdf/10.1177/1536867X1001000302) to detect outliers in multivariate data, what I do here is predict an income/earnings value based on simple OLS, and then use bacon to determine whether observed values should be considered outliers, given the fitted value for income/earnings. The key parameter we as researchers need to determine, somewhat arbitrarily, is the "percentile" value. This is "the 1 − # percentile of the chi-squared distribution to be used as a threshold to separate outliers from nonoutliers" where a "larger # identifies a larger proportion of the sample as outliers.". 
	
	gen w6_hhincome_ln = log(w6_hhincome)
	gen w6_hhincome_lb_ln = log(w6_hhincome_lb)
	gen w6_eminc_apr_imp_ln = log(w6_eminc_apr_imp)
	
	
	cap drop w6_hhincome_hat
	reg w6_hhincome_ln w6_age w6_hhsizer i.w6_race i.w6_area i.w6_occu i.w6_educ_bins i.w6_gender i.w6_prov [aw=w6_wgt], r 
	predict w6_hhincome_hat	

	cap drop out_hhinc
	bacon w6_hhincome_ln w6_hhincome_hat, generate(out_hhinc) percentile(0.15) replace
	*scatter w6_hhincome_ln w6_hhincome_hat, ml(out_hhinc) ms(i) note("0 = nonoutlier, 1 = outlier")
	*tw (kdensity w6_hhincome_ln  if out_hhinc ==0 [aw=w6_wgt] ) (kdensity w6_hhincome_ln [aw=w6_wgt] ), leg(on order(1 "No outliers" 2 "Raw") pos(6) row(1))	//makes quite a bit of difference in density 
	
***	Earnings
	cap drop w6_eminc_apr_imp_hat
	reg w6_eminc_apr_imp_ln w6_age i.w6_race i.w6_area i.w6_occu i.w6_educ_bins i.w6_gender i.w6_prov if w6_empl_stat ==3 [aw=w6_wgt], r
	predict w6_eminc_apr_imp_hat	

	cap drop out_eminc
	bacon w6_eminc_apr_imp_ln w6_eminc_apr_imp_hat, generate(out_eminc) percentile(0.20) replace 
	*scatter w6_eminc_apr_imp_ln w6_eminc_apr_imp_hat if w6_empl_stat ==3 , ml(out_eminc) ms(i) note("0 = nonoutlier, 1 = outlier")
	*tw (kdensity w6_eminc_apr_imp_ln  if out_eminc ==0 [aw=w6_wgt] ) (kdensity w6_eminc_apr_imp_ln [aw=w6_wgt] ), leg(on order(1 "No outliers" 2 "Raw") pos(6) row(1))	//doesn't make much difference

	
// 3. Various cleaned income variables
*===============================================================================
***	Main respondent from NIDS
	gen temp = w5_h_respondent if w6_outcome ==1
	gen w6_NIDShhrespondent = 0
	replace w6_NIDShhrespondent = 1 if temp ==pid
	drop temp

	tab w6_NIDShhrespondent [aw=w6_wgt], sum(w6_hhincome)
	
***	Income raw
	gen w6_hhincome_raw = w6_hhincome if w6_outcome==1
	
***	Income w/o outliers
	gen w6_hhincome_cl = w6_hhincome if w6_outcome==1
	replace w6_hhincome_cl = . if out_hhinc ==1 & w6_outcome==1 //13 outliers 
	
***	Income w/ LB imputation
	gen w6_hhincome_imp = w6_hhincome_cl if w6_outcome==1
	replace w6_hhincome_imp = w6_hhincome_lb if w6_hhincome_lb > w6_hhincome_cl & w6_hhincome_lb !=. & w6_outcome==1 //1836 replaced out of 4395
	
***	Log of all our new hhincome vars + NIDS W5 vars
	foreach var in w6_hhincome_raw w6_hhincome_cl w6_hhincome_imp w5_hhq_inc w5_hhincome  {
	gen `var'_ln = log(`var')
	}

*===============================================================================
***	Generating a "best-guess" household variable - using children as easier to report on this than HH_size as a whole 
*===============================================================================
	
	drop if mi(w5_hhid)
	
	* create w6_hhid as indicating the unique combinations of w6_hhsizer w6_dc2011 w6_hhid
	egen w6_guess_hhid = group(w6_tot_child w6_dc2011 w5_hhid) if w6_outcome == 1 & !mi(w6_tot_child) & !mi(w6_dc2011)
	bys w6_guess_hhid: gen w6_guess_hhpersonno = _n if !mi(w6_guess_hhid)		
	bys w6_guess_hhid: gen w6_guess_hhmatchsize = _N if !mi(w6_guess_hhid)		// number of people in each of these "best-guess" households
	egen w6_guess_hhmtag = tag(w6_guess_hhid) if !mi(w6_guess_hhid)				// tag one observation per "best_guess" household

	*tab w6_guess_hhmatchsize if w6_guess_hhmtag == 1 & w6_outcome == 1, m
*===============================================================================
***	END
*===============================================================================
